@@ -1,6 +1,5 @@
 /* XXXVISHY - lets try to keep it all in aimHelpers
 
-
 var allEnums = null;
 
 function getEnums( myInterface )
@@ -103,7 +102,7 @@ function aimBuddyAddBuddyBefore(groupName, screenName, beforeBuddy)
 	return 0;
 }
 
-function aimBuddyAddBuddyAfter(groupName, screenName, afterBuddy, dispname, service, emailaddress)
+function aimBuddyAddBuddyAfter(groupName, screenName, afterBuddy, dispname, service)
 {
   var pIAimBuddy = aimBuddyManager();
   if (afterBuddy == "")
@@ -116,33 +115,20 @@ function aimBuddyAddBuddyAfter(groupName, screenName, afterBuddy, dispname, serv
       aimErrorBox(msg);
       return 1;
     }
-    if(!isIcq()) 
-    {
-      var cp = new String(screenName);
-      if (!IsValidChar(cp)){
-        // Cannot contain invalid characters 
-        aimErrorBox(aimString("msg.BadScreenName"));
-        return 1;
-      }
-    }
-  
     if (afterBuddy)
-      pIAimBuddy.AddBuddy(groupName, screenName, afterBuddy, aimInsertionStyles().InsertAfter, dispname, emailaddress);
+      pIAimBuddy.AddBuddy(groupName, screenName, afterBuddy, aimInsertionStyles().InsertAfter, dispname);
     else
-      pIAimBuddy.AddBuddy(groupName, screenName, afterBuddy, aimInsertionStyles().InsertEnd, dispname, emailaddress);
+      pIAimBuddy.AddBuddy(groupName, screenName, afterBuddy, aimInsertionStyles().InsertEnd, dispname);
 
-    if((!isIcq()) && (emailaddress != null)) {
-      aimFeedbagManager().SetEmailId(screenName, emailaddress);
-    }
   }
-  
   if (service == 1) {
-     // user entered all numbers, so icq service
+    // user entered all numbers, so icq service
     aimBuddyManager().SetIfIcqUserinDS(screenName, true);
     aimFeedbagManager().SetDisplay(groupName, screenName, dispname); 
   }
-  else  
+  else 
     aimBuddyManager().SetIfIcqUserinDS(screenName, false);
+  
 
   return 0;
 }
@@ -211,5 +197,3 @@ function aimBuddyExportBuddyList(fileSpec, status)
 	return false; 
 */
 }
-
-
