@@ -15,10 +15,9 @@ var IsSidebar = true;
 
 function CheckIfApp(inType)
 {
-  const nsIWindowMediator = Components.interfaces.nsIWindowMediator;
-  var windowManager = Components.classes['@mozilla.org/appshell/window-mediator;1'].getService(nsIWindowMediator);
-  //var windowManagerInterface = windowManagerDS.QueryInterface( Components.interfaces.nsIWindowMediator);
-  var topWindow = windowManager.getMostRecentWindow( inType );
+  var windowManager = Components.classes['@mozilla.org/rdf/datasource;1?name=window-mediator'].getService();
+  var windowManagerInterface = windowManager.QueryInterface( Components.interfaces.nsIWindowMediator);
+  var topWindow = windowManagerInterface.getMostRecentWindow( inType );
   if (topWindow) {
       IsApp=true;
       return true
@@ -43,4 +42,4 @@ function CheckIfSidebar()
       return false;
     }
   return true;
-}      
+}      
\ No newline at end of file
