@@ -52,27 +52,13 @@ function AimAppOnWndLoad()
 	gFirstTime = 0;
 
 	setTimeout("CheckBuddyPanel()",500);
-      
+    
   setAdTimer();
 
   updateCurrentAppWindow();
 
   addAppSessionListener();
 
-  var supportmailim = aimPrefsManager().GetBoolPref("aim.session.supportmailim", null, false);
-  if (!supportmailim) {
-    document.getElementById("menu_switchview").setAttribute("hidden", "true");
-    document.getElementById("menu_editbuddyinfo").setAttribute("hidden", "true");
-    //document.getElementById("context-editdispname").setAttribute("hidden", "true");
-    //document.getElementById("context-updateemail").setAttribute("hidden", "true");
-    document.getElementById("preemailseperator").setAttribute("hidden", "true");
-    document.getElementById("context-sendemail").setAttribute("hidden", "true");
-    document.getElementById("emailseperator").setAttribute("hidden", "true");
-    document.getElementById("viewseparator").setAttribute("hidden", "true");
-    document.getElementById("context-checkemail").setAttribute("hidden", "true");
-  }
-    
-
   setTimeout("aimSession().SetAppIcon()", 1000);
 
 
@@ -151,10 +137,9 @@ function cmdNewChat(invScreenName,invProposal,invScreenNames,toExistingWindow,in
   }
   else
   {
-    //App is aim - in this case shift-ctrl-C which invokes cmdNewchat should bring up add Contact window.
-    cmdAddBuddy();
+   //App is aim - in this case shift-ctrl-C which invokes cmdNewchat should bring up add Contact window.
+      cmdAddBuddy();
   }
-
 }
 
 /*
@@ -250,7 +235,7 @@ function getSelectedBuddiesFromList()
           var buddyName = GetBuddyAttribute(tree, buddyResource, "ScreenName");
           if (!CheckForDuplicateInArray(selectedBuddies, buddyName)) {
             selectedBuddies[buddyCount++] = buddyName;
-        }
+          }
         }
 
 
@@ -482,12 +467,6 @@ function cmdExportBuddyList()
 
 function cmdImportBuddyList()
 {
-  var feedbag = aimFeedbagManager();
-  var flag = feedbag.CheckFeedbag();
-  if (!flag) {
-    aimErrorBox(aimString("msg.feedbagdown"));
-    return;
-  }
 
 	nsIFilePicker = Components.interfaces.nsIFilePicker;
 	var fp = Components.classes["@mozilla.org/filepicker;1"].createInstance(nsIFilePicker);
@@ -532,13 +511,6 @@ function cmdSignOffAndClose()
 
 function cmdAddBuddy()
 {
-  var feedbag = aimFeedbagManager();
-  var flag = feedbag.CheckFeedbag();
-  if (!flag) {
-    aimErrorBox(aimString("msg.feedbagdown"));
-    return;
-  }
-
   var sidebarframe=getsidebarframe();
 	var foundOne = false;
 	var selectedGroup = "";
@@ -557,7 +529,7 @@ function cmdAddBuddy()
 
   var groups = aimGetSelectedBuddyGroups();
 	openDialog("chrome://aim/content/BuddyAddBuddy.xul", "", 
-		"modal=yes,titlebar,chrome", groups, tree, null, null);
+		"modal=yes,titlebar,chrome", groups, tree, null);
 }
 
 /*
@@ -577,12 +549,6 @@ function cmdAddBuddy()
 
 function cmdAddGroup()
 {
-  var feedbag = aimFeedbagManager();
-  var flag = feedbag.CheckFeedbag();
-  if (!flag) {
-    aimErrorBox(aimString("msg.feedbagdown"));
-    return;
-  }
 	openDialog("chrome://aim/content/BuddyAddGroup.xul", "", "modal=yes,titlebar,chrome");
 }
 
@@ -636,13 +602,6 @@ function SelectedBuddy()
 
 function cmdDelete()
 {
-  var feedbag = aimFeedbagManager();
-  var flag = feedbag.CheckFeedbag();
-  if (!flag) {
-    aimErrorBox(aimString("msg.feedbagdown"));
-    return;
-  }
-
   var tree = getSelectedTreeName();
   var col = getSelectedTabName();
   var selectedBuddies = new Array();
@@ -753,6 +712,7 @@ function cmdDelete()
   } //for
 
 
+
   var answer;
   var hasCancelled = 0;
   for (var g=0; g<selectedGroups.length; g++) {
@@ -763,9 +723,8 @@ function cmdDelete()
       else {
         answer = top.confirm(aimString("confirm.DeleteGroup_ICQ").replace(/%GroupName%/, selectedGroups[g].name));
         }
-      if (answer == true) {
+      if (answer == true)
         aimBuddyRemoveBuddyGroup(selectedGroups[g].name);
-      }
       else
         if (!hasCancelled)
           hasCancelled = 1;
@@ -774,11 +733,12 @@ function cmdDelete()
 
   for (var b=0; b<selectedBuddies.length; b++) {
     if (selectedBuddies[b].name != null && selectedBuddies[b].name != "" ) {
-      if (isIcq() != true)
+      if (isIcq() != true ) {
         answer  = top.confirm(aimString("confirm.DeleteBuddy").replace(/%BuddyName%/, selectedBuddies[b].name).replace(/%GroupName%/, selectedBuddies[b].parentname));
-      else
+        }
+      else {
         answer  = top.confirm(aimString("confirm.DeleteBuddy_ICQ").replace(/%BuddyName%/, selectedBuddies[b].name).replace(/%GroupName%/, selectedBuddies[b].parentname));
-
+        }
       if (answer == true) {
         if (selectedBuddies[b].parentname == aimString("msg.AuthGroup")) {
            // If this is the Awaiting authorization special group remove from feedbag and datasource
@@ -787,14 +747,13 @@ function cmdDelete()
            continue;
         }
         aimBuddyRemoveBuddy(selectedBuddies[b].parentname, selectedBuddies[b].name);
-      }
+     }
       else
         if (!hasCancelled)
           hasCancelled = 1;
     }
   }
 
-  
   var totalRowCount = view.rowCount;
   if (!hasCancelled) {
     // The view maintains the selection if the user has cancelled the deletion. So don't worry about selecting the
@@ -805,6 +764,7 @@ function cmdDelete()
     else
       SelectIndex(lastSelectedIndex);
   }
+
 }
 
 
@@ -925,7 +885,9 @@ try {
         //Sidebar panels file does not exist?
         return;
       }
-      return aimFileProtocolHandler().getURLSpecFromFile(sidebar_file);
+		var file_url = Components.classes["@mozilla.org/network/standard-url;1"].createInstance(Components.interfaces.nsIFileURL);
+		file_url.file = sidebar_file;
+	    return file_url.spec;
     } catch (ex) {
        throw(ex);
     }
@@ -998,8 +960,7 @@ function CheckBuddyPanel()
       this.datasource.QueryInterface(nsIRDFRemoteDataSource).Flush();
 	  }
 	} 
-  if(!SidebarSelectPanel(document.getElementById("urn:sidebar:panel:im-panel"), true, true))
-	SidebarTogglePanel(document.getElementById("urn:sidebar:panel:im-panel"));
+  SidebarSelectPanel(document.getElementById("urn:sidebar:panel:im-panel"), false, false);
 }
 
  
@@ -1083,121 +1044,116 @@ function fillInfoTooltip(aEvent, aTooltipNode)
   * Event listener used for RequestUserInfoCapabilities
   ******/
  
-function TooltipCapListener(aTreecell, aTooltip)
-{
-  this.mTreecell = aTreecell;
-  this.mTooltip = aTooltip;
-}
+ function TooltipCapListener(aTreecell, aTooltip)
+ {
+   this.mTreecell = aTreecell;
+   this.mTooltip = aTooltip;
+ }
  
-TooltipCapListener.prototype = {
-  OnRequestUserInfoCapabilitiesComplete: function(aScreenName, aUserObj)
-  {
-    var now = new Date().getTime()/1000;
-    // TODO: search within mTooltip for text elements instead of id search
-    // fill the screen name
-    var elName = document.getElementById("infoTooltipName");
-  
-    aimABInfo = aimManager().QueryInterface(Components.interfaces.nsIAimABInfo);
-    if (aimABInfo) {
-      var card = aimABInfo.getPersonalAbCardFromAttribute("_AimScreenName", aScreenName, false);
-      if (card) {
-        if (card.nickName)
-          elName.setAttribute("value", card.nickName);
-        else
-          if (card.displayName)
-            elName.setAttribute("value", card.displayName);
-          else
-            elName.setAttribute("value", aScreenName);
-      }
-      else
-        elName.setAttribute("value", aScreenName);
-    }
-    else
-      elName.setAttribute("value", aScreenName);
-
-    
-    // fill the online line
-    var elOnline = document.getElementById("infoTooltipOnlineTime");
-    var since = aUserObj.GetOnlineSinceTime();
-    elOnline.setAttribute("value", getPrettyDateDiff(now, since));
-    var elOnlineId = document.getElementById("infoTooltipOnlineTimeId");
-    elOnlineId.setAttribute("value", aimString("tooltip.online") + ":");
+ TooltipCapListener.prototype = {
+	OnRequestUserInfoCapabilitiesComplete: function(aScreenName, aUserObj)
+ 	{
+     var now = new Date().getTime()/1000;
+     // TODO: search within mTooltip for text elements instead of id search
      
-    // fill the status line
-    var elStatus = document.getElementById("infoTooltipStatus");
-    var elStatusTime = document.getElementById("infoTooltipStatusTime");
-    if (aUserObj.IsIdle()) {
-      elStatus.setAttribute("value", aimString("tooltip.idle") + ":");
-      var statusDate = aUserObj.GetIdleSinceTime();
-      elStatusTime.setAttribute("value", getPrettyDateDiff(now, statusDate));
-    }
-    else
-      if (aUserObj.IsAway()) {
-        elStatus.setAttribute("value", aimString("tooltip.status") + ":");
-        elStatusTime.setAttribute("value", aimString("tooltip.away"));
-      }
-      else {
-        elStatus.setAttribute("value", aimString("tooltip.status") + ": ");
-        elStatusTime.setAttribute("value", aimString("tooltip.active"));
-      }
+     // fill the screen name
+     var elName = document.getElementById("infoTooltipName");
+  
+     aimABInfo = aimManager().QueryInterface(Components.interfaces.nsIAimABInfo);
+     if (aimABInfo) {
+        var card = aimABInfo.getPersonalAbCardFromAttribute("_AimScreenName", aScreenName, false);
+        if (card) {
+          if (card.nickName)
+            elName.setAttribute("value", card.nickName);
+          else if (card.displayName)
+            elName.setAttribute("value", card.displayName);
+               else
+            elName.setAttribute("value", aScreenName);
+          }
+		  else
+          elName.setAttribute("value", aScreenName);
+     }
+	 else
+       elName.setAttribute("value", aScreenName);
 
-    if (isIcq() != true ) 
-    {  
-
-    // fill the warnings line
-    var warnings = document.getElementById("infoTooltipWarnings");
-    warnings.setAttribute("value", aUserObj.GetWarningPercent() + "%");
-    var warningsId = document.getElementById("infoTooltipWarningsId");
-    warningsId.setAttribute("value", aimString("tooltip.warnings") + ":");
-    var cp = new String(aScreenName);
-    if ((cp.charCodeAt(0) > 47) && (cp.charCodeAt(0) < 58))
-    {
+     
+   // fill the online line
+   var elOnline = document.getElementById("infoTooltipOnlineTime");
+   var since = aUserObj.GetOnlineSinceTime();
+   elOnline.setAttribute("value", getPrettyDateDiff(now, since));
+	 var elOnlineId = document.getElementById("infoTooltipOnlineTimeId");
+   elOnlineId.setAttribute("value", aimString("tooltip.online") + ":");
+   
+   // fill the status line
+   var elStatus = document.getElementById("infoTooltipStatus");
+	 var elStatusTime = document.getElementById("infoTooltipStatusTime");
+   if (aUserObj.IsIdle()) {
+     elStatus.setAttribute("value", aimString("tooltip.idle") + ":");
+     var statusDate = aUserObj.GetIdleSinceTime();
+     elStatusTime.setAttribute("value", getPrettyDateDiff(now, statusDate));
+   } else if (aUserObj.IsAway()) {
+	   elStatus.setAttribute("value", aimString("tooltip.status") + ":");
+     elStatusTime.setAttribute("value", aimString("tooltip.away"));
+   } else {
+	  elStatus.setAttribute("value", aimString("tooltip.status") + ": ");
+    elStatusTime.setAttribute("value", aimString("tooltip.active"));
+   }
+   
+   if (isIcq() != true ) 
+   {  
+     // fill the warnings line
+     var warnings = document.getElementById("infoTooltipWarnings");
+     warnings.setAttribute("value", aUserObj.GetWarningPercent() + "%");
+	   var warningsId = document.getElementById("infoTooltipWarningsId");
+     warningsId.setAttribute("value", aimString("tooltip.warnings") + ":");
+     var cp = new String(aScreenName);
+     if ((cp.charCodeAt(0) > 47) && (cp.charCodeAt(0) < 58)) 
+     {
       // is an icq number, do not show warnings
       warningsId.setAttribute("hidden", "true");
       warnings.setAttribute("hidden", "true");
-    }
-    else
-    {
+     }
+     else
+     {
       warningsId.setAttribute("hidden", "false");
       warnings.setAttribute("hidden", "false");
-    }
+     }
 
-    // fill in the Service Type (AOL, Internet, Administrator...)     
-    var elFlagService = document.getElementById("infoTooltipFlagValue");
-    var flagServiceValue = aUserObj.GetFlags();
-    var serviceString = "";
-    var serviceEnums = Components.interfaces.nsAimServiceTypes;
-    if (flagServiceValue & serviceEnums.Transient)
-      serviceString = aimString("IdsflagTrial.label") + " ";
-    if (flagServiceValue & serviceEnums.Aol)
-      serviceString = serviceString + aimString("IdsflagAol.label") + " ";
-    if (flagServiceValue & serviceEnums.Free)
-      serviceString = serviceString + aimString("IdsflagInternet.label") + " ";
-    if (flagServiceValue & serviceEnums.Administrator)
-      serviceString = serviceString + aimString("IdsflagAdministrator.label") + " ";
-    if (flagServiceValue & serviceEnums.Mobile)
-      serviceString = serviceString + aimString("IdsflagMobile.label") + " ";
-    
-    elFlagService.setAttribute("value", serviceString);
-    var elFlagServiceId = document.getElementById("infoTooltipFlag");
-    elFlagServiceId.setAttribute("value", aimString("tooltip.service") + ":");
-    elFlagService.setAttribute("hidden", "false");
-    elFlagServiceId.setAttribute("hidden", "false");
+     
+  // fill in the Service Type (AOL, Internet, Administrator...)     
+	 var elFlagService = document.getElementById("infoTooltipFlagValue");
+	 var flagServiceValue = aUserObj.GetFlags();
+	 var serviceString = "";
+	 var serviceEnums = Components.interfaces.nsAimServiceTypes;
+	 if (flagServiceValue & serviceEnums.Transient)
+		serviceString = aimString("IdsflagTrial.label") + " ";
+	 if (flagServiceValue & serviceEnums.Aol)
+		serviceString = serviceString + aimString("IdsflagAol.label") + " ";
+	 if (flagServiceValue & serviceEnums.Free)
+	    serviceString = serviceString + aimString("IdsflagInternet.label") + " ";
+	 if (flagServiceValue & serviceEnums.Administrator)
+	    serviceString = serviceString + aimString("IdsflagAdministrator.label") + " ";
+	 
+   elFlagService.setAttribute("value", serviceString);
+	 var elFlagServiceId = document.getElementById("infoTooltipFlag");
+   elFlagServiceId.setAttribute("value", aimString("tooltip.service") + ":");
+   elFlagService.setAttribute("hidden", "false");
+   elFlagServiceId.setAttribute("hidden", "false");
 
-    // fill in the Capabilities
-    var elCapabilities = document.getElementById("capabilitiesValue");
-    var elCapabilitiesId = document.getElementById("capabilities");
-    elCapabilitiesId.setAttribute("hidden", "false");
-    elCapabilities.setAttribute("hidden", "false");
-    try {
+     
+  // fill in the Capabilities
+	var elCapabilities = document.getElementById("capabilitiesValue");
+  var elCapabilitiesId = document.getElementById("capabilities");
+  elCapabilitiesId.setAttribute("hidden", "false");
+  elCapabilities.setAttribute("hidden", "false");
+	try {
+		var capMask = aUserObj.GetCapabilities();
+    if (capMask == 0) {
+      elCapabilitiesId.setAttribute("hidden", "true");
+      elCapabilities.setAttribute("hidden", "true");
+    } else {
+      var capEnums = Components.interfaces.nsAimCapabilitesMask;
       var capString = "";
-      var capMask = aUserObj.GetCapabilities();
-      if (capMask == 0) {
-        elCapabilitiesId.setAttribute("hidden", "true");
-        elCapabilities.setAttribute("hidden", "true");
-      }
-      else {
-        var capEnums = Components.interfaces.nsAimCapabilitesMask;
         if (capEnums.buddyIcon & capMask) {
           if (capString == "")
             // if it is the first capability, just add it
@@ -1224,76 +1180,57 @@ TooltipCapListener.prototype = {
           else
             capString += ", "+aimString("tooltip.unification");
         }
-
-        elCapabilitiesId.setAttribute("value", aimString("tooltip.capabilities") + ":");
-        elCapabilities.setAttribute("value", capString);
-
-      }
+         
+      elCapabilities.setAttribute("value", capString);
+      elCapabilitiesId.setAttribute("value", aimString("tooltip.capabilities") + ":");
     }
-    catch (e) {}
-
-    var supportmailim = aimPrefsManager().GetBoolPref("aim.session.supportmailim", null, false);
-    if (!supportmailim) {
-      document.getElementById("displayName").setAttribute("hidden", "true");
-      document.getElementById("displayNameValue").setAttribute("hidden", "true");
-      document.getElementById("email").setAttribute("hidden", "true");
-      document.getElementById("emailValue").setAttribute("hidden", "true");
-    }
-    else {
+	} catch (e) {}
+  
       // fill the Display Name line
-      var dnValue = document.getElementById("displayNameValue");
-      var curDispName = aimFeedbagManager().GetDispName(aScreenName);
-      if (curDispName)
-        dnValue.setAttribute("value", curDispName);
-      else
-        dnValue.setAttribute("value", aimString("tooltip.unknown"));
-      var displayName = document.getElementById("displayName");
-      displayName.setAttribute("value", aimString("tooltip.displayName") + ":");
-      displayName.setAttribute("hidden", "false");
-      dnValue.setAttribute("hidden", "false");
-
-      // fill the Email Address line
-      var emailValue = document.getElementById("emailValue");
-      var curEmail = aimFeedbagManager().GetEmailId(aScreenName);
-      if (curEmail)
-        emailValue.setAttribute("value", curEmail);
-      else
-        emailValue.setAttribute("value", aimString("tooltip.unknown"));
-      var emailName = document.getElementById("email");
-      emailName.setAttribute("value", aimString("tooltip.emailName") + ":");
-      emailName.setAttribute("hidden", "false");
-      emailValue.setAttribute("hidden", "false");
-    }
-    }
-    else
-    {
-      document.getElementById("capabilitiesValue").setAttribute("hidden", "true");
-      document.getElementById("capabilities").setAttribute("hidden", "true");
-      document.getElementById("infoTooltipWarningsId").setAttribute("hidden", "true");
-      document.getElementById("infoTooltipWarnings").setAttribute("hidden", "true");
-      document.getElementById("infoTooltipFlag").setAttribute("hidden", "true");
-      document.getElementById("infoTooltipFlagValue").setAttribute("hidden", "true");
-      document.getElementById("displayName").setAttribute("hidden", "true");
-      document.getElementById("displayNameValue").setAttribute("hidden", "true");
-      document.getElementById("email").setAttribute("hidden", "true");
-      document.getElementById("emailValue").setAttribute("hidden", "true");
-      
-       //Hide warning capabilities etc in Icq     
-    }
-    // show the tooltip
-    // if this is a mac do this bad hack to hide the tooltip
-    if (navigator.appVersion.indexOf("Macintosh") != -1)
-      document.getElementById("hideload").removeAttribute("collapsed");
-    else
-      this.mTooltip.removeAttribute("collapsed");
-      this.mTreecell._RequestingInfo = false;
-  },
- 
-  OnRequestUserInfoCapabilitiesError: function(aScreenName, aError)
-  {
-    this.mTreecell._RequestingInfo = false;
+  var dnValue = document.getElementById("displayNameValue");
+  var curDispName = aimFeedbagManager().GetDispName(aScreenName);
+  var displayName = document.getElementById("displayName");
+  if (curDispName != null) {
+    dnValue.setAttribute("value", curDispName);
+    displayName.setAttribute("value", aimString("tooltip.displayName") + ":");
+    displayName.setAttribute("hidden", "false");
+    dnValue.setAttribute("hidden", "false");
   }
-};
+  else {
+    displayName.setAttribute("hidden", "true");
+    dnValue.setAttribute("hidden", "true");
+  }
+
+   
+     
+
+  } //end if icq
+  else
+  {
+    //Hide warning capabilities etc in Icq     
+    document.getElementById("infoTooltipWarningsId").setAttribute("hidden", "true");
+    document.getElementById("infoTooltipWarnings").setAttribute("hidden", "true");
+    document.getElementById("infoTooltipFlag").setAttribute("hidden", "true");
+    document.getElementById("infoTooltipFlagValue").setAttribute("hidden", "true");
+    document.getElementById("capabilitiesValue").setAttribute("hidden", "true");
+    document.getElementById("capabilities").setAttribute("hidden", "true");
+    
+  }
+
+     // show the tooltip
+     // if this is a mac do this bad hack to hide the tooltip
+     if (navigator.appVersion.indexOf("Macintosh") != -1)
+	     document.getElementById("hideload").removeAttribute("collapsed");
+	 else
+	     this.mTooltip.removeAttribute("collapsed");
+     this.mTreecell._RequestingInfo = false;
+ 	},
+ 
+	OnRequestUserInfoCapabilitiesError: function(aScreenName, aError)
+ 	{
+     this.mTreecell._RequestingInfo = false;
+ 	}
+ };
  
 
 function cmdChangePassword() {
@@ -1326,13 +1263,12 @@ function cmdGetMemberInfo() {
 
 function cmdBuddyAlert(isedit) {
   var screenName = getSelectedScreenName();
-  var groupName = getGroupForScreenName();
-  if (screenName && (screenName != null) && groupName && (groupName != null)) 
+  if (screenName && (screenName != null)) 
   {
     if (isedit == 1)
-      window.openDialog('chrome://aim/content/AimBuddyAlert.xul','_blank','chrome,all,dialog=no', screenName, groupName, 1);
+      window.openDialog('chrome://aim/content/AimBuddyAlert.xul','_blank','chrome,all,dialog=no', screenName, 1);
     else  
-      window.openDialog('chrome://aim/content/AimBuddyAlert.xul','_blank','chrome,all,dialog=no', screenName, groupName, null);
+      window.openDialog('chrome://aim/content/AimBuddyAlert.xul','_blank','chrome,all,dialog=no', screenName, null);
   }
 }
 
@@ -1348,18 +1284,16 @@ function cmdBuddyAlert(isedit) {
 
 function cmdDelBuddyAlert() {
   var screenName = getSelectedScreenName();
-  var groupName = getGroupForScreenName();
-  if (screenName && (screenName != null) && groupName && (groupName != null))
-    aimBuddyManager().DeleteBuddyFromAlertList(screenName, groupName); 
+  if (screenName && (screenName != null))
+    aimBuddyManager().DeleteBuddyFromAlertList(screenName); 
 }
 
 function cmdNewAway()
 {
-  if (isIcq())
+  if (isIcq() == true )
     window.openDialog("chrome://aim/content/AddIcqAwayMessage.xul","_blank", "chrome,close,titlebar,modal", "", "", "");
-  else {
-    window.openDialog("chrome://aim/content/AddAwayMessage.xul","_blank", "chrome,close,titlebar,modal", "", "", "", true);
-  }
+  else
+    window.openDialog("chrome://aim/content/AddAwayMessage.xul","_blank", "chrome,close,titlebar,modal", "", "", "");
 }
 
 function sendFile()
@@ -1401,7 +1335,8 @@ var sessionAppObserver = {
 function cmdRegistUser()
 {
  // Open regist user url;
-  regLink = aimRegionString("icq.register.url");
+  regLink = aimString("icq.register.url");
+  dump("SURESH: regLink = " + regLink + "\n");
   openTopWin(regLink);  
   return;
 }
@@ -1449,20 +1384,22 @@ function cmdRename()
    var tree = getSelectedTreeName();
    var currentIndex = tree.currentIndex;
    var rangeCount = tree.treeBoxObject.selection.getRangeCount();
-   if (rangeCount != 1 || user == null) { 
+   if (rangeCount > 1 || rangeCount < 1) { 
      // We dont support multiple selectetion for rename :-(
      aimErrorBox(aimString("msg.SelectContact"));
      return;
-   }
+     }
    var view = tree.treeBoxObject.view;
    var parentIndex = view.getParentIndex(currentIndex);
    if (currentIndex > 0) {
        var groupResource = GetBuddyResource(tree, parentIndex);
        var groupName = GetBuddyAttribute(tree, groupResource, "Name");
    }
-
-   openDialog("chrome://aim/content/RenameBuddy.xul", "", "modal=yes,titlebar,chrome,centerscreen", groupName, user);
-
+   if (user) {
+     openDialog("chrome://aim/content/RenameBuddy.xul", "", "modal=yes,titlebar,chrome,centerscreen", groupName, user);
+   }
+   else
+     aimErrorBox(aimString("msg.SelectContact"));
 }
 
 
@@ -1482,11 +1419,10 @@ function cmdRequestAuth()
   var user=getSelectedScreenName();
   var isinlist = new Object();
   aimFeedbagManager().IsInAuthList(user, isinlist);
-  // Ifin auth await group open rerequest auth window
+   // Ifin auth await group open rerequest auth window
   if (isinlist.value == true) {
     window.openDialog('chrome://aim/content/icqAuthOutgoing.xul','_blank','chrome,all,dialog=no',user, auth_msg);
     }
   else
     aimErrorBox(aimString("msg.authtryagain"));  
-}
-
+}
\ No newline at end of file
