@@ -7,21 +7,34 @@ var showTimestampVal;
 var isChatContent = false;
 var firstSend = 1;
 
-//this variable is used for checking the typing indicator pref (in Privacy pane) after an IM is sent.
-//We send typing indicators based on this pref.
-var gTypingPref = checkTypingPref();
+/*
+ * IMDocumentStateListener is the listener which the IM compose window uses.
+ * NotifyDocumentCreated gets called by the editor whenever there is some change in the
+ * compose window. If there is any IM message from the input arguments, then that is added 
+ * to the compose window and the send button is enabled.
+*/
 
-//This variable is used to check whether we need to send an event. This variable is reset everytime 
-//the typing indicator flag changes (Typing, NotEmpty etc).
-var gSendTypingEvent = 1;
+var IMDocumentStateListener =
+{
+  NotifyDocumentCreated: function() 
+  {
+  setTimeout("sendButtonListeners()",0);
+  var nsIPlaintextEditor = Components.interfaces.nsIPlaintextEditor;
+  window.editorShell.editor.flags |= nsIPlaintextEditor.eEditorNoCSSMask;
+  if ( message != "" ) {
+    window.editorShell.InsertText(message);
+    EnableSendButton();
+  }
 
-//This variable is used to send Non Empty typing event
-var gSendNonEmptyEvent = 0;
+  },
 
-var gTypingTimeoutid;
-
-var gTypingEnum = Components.interfaces.nsAimInputStateFlags;
-var gEditorLength;
+  NotifyDocumentWillBeDestroyed: function() {},
+  NotifyDocumentStateChanged:function( isNowDirty ) {
+    // If the document is not empty, enable the send button
+     if (isNowDirty)
+       EnableSendButton();
+  }
+};
 
 /*
  * Function:  KnockKnockAddDenyList()
@@ -75,17 +88,7 @@ function pokeKnockKnockMessage(scname)
 {
   var msg = aimString("knock.msg");
   var warning = aimString("knock.warning");
-  var message = aimString("knock.preamble").replace(/%ScreenName%/, scname);
-
-  if (isIcq()) {
-    var icqmsg = aimString("knock.icqmsg");
-    var icqelement = document.getElementById("IMKnockKnockIcqMsg");
-    var icqtextNode = document.createTextNode(icqmsg);
-    icqelement.appendChild(icqtextNode);
-  }
-  else {
-    document.getElementById("IMKnockKnockIcqMsg").setAttribute("hidden", true);
-  }
+  var message = aimString("knock.preamble").replace(/%ScreenName%/, scname); 
 
   var element = document.getElementById("IMKnockKnockHtml");
   var textNode = document.createTextNode(message);
@@ -189,32 +192,6 @@ function AimIMOnWndLoad()
   updateCurrentComposeWindow();
 
   window.setTimeout('delayedOnWndLoad()', 0);
-  document.getElementById("paragraphMenu").setAttribute("hidden", true);
-  document.getElementById("listMenu").setAttribute("hidden", true);
-  document.getElementById("decreaseIndent").setAttribute("hidden", true);
-  document.getElementById("increaseIndent").setAttribute("hidden", true);
-  document.getElementById("alignMenu").setAttribute("hidden", true);
-  document.getElementById("tableMenu").setAttribute("hidden", true);
-  document.getElementById("objectProperties").setAttribute("hidden", true);
-  document.getElementById("removeLinksMenuitem").setAttribute("hidden", true);
-  document.getElementById("removeNamedAnchorsMenuitem").setAttribute("hidden", true);
-
-  document.getElementById("removeSep").setAttribute("hidden", true);
-  document.getElementById("tabSep").setAttribute("hidden", true);
-  document.getElementById("identingSep").setAttribute("hidden", true);
-  document.getElementById("tableSep").setAttribute("hidden", true);
-
-  //hide some insert menuitems
-  document.getElementById("insertImage").setAttribute("hidden", true);
-  document.getElementById("insertTable").setAttribute("hidden", true);
-  document.getElementById("insertAnchor").setAttribute("hidden", true);
-  document.getElementById("insertHline").setAttribute("hidden", true);
-  document.getElementById("insertHTMLSource").setAttribute("hidden", true);
-  document.getElementById("insertChars").setAttribute("hidden", true);
-  document.getElementById("insertTOC").setAttribute("hidden", true);
-  document.getElementById("insertMenuSeparator").setAttribute("hidden", true);
-  document.getElementById("insertBreakAll").setAttribute("hidden", true);
-
 }
 
 /*
@@ -262,16 +239,6 @@ function delayedOnWndLoad()
         if (encryptStatus) {
           encryptStatus.removeAttribute("hidden");
         }
-        if (capEnums.unicode & capMask)
-        {
-          alert("unicode");
-          document.getElementById("unicode").setAttribute("value", "1");
-        }
-        else
-        {
-          alert("not unicode");
-          document.getElementById("unicode").setAttribute("value", "");
-        }
       }
     }
   }
@@ -315,42 +282,14 @@ function delayedOnWndLoad()
   StartConversation();
 }
 
-function composeKeyPress(event)
-{
-  var editor = GetCurrentEditor();
-  if (!editor)
-    return;
-
-  var screenName = AimIMGetFormScreenName();
-  if (gTypingPref && gSendTypingEvent) {
-    aimIM().SetInputStateFlag(gTypingEnum.Typing, screenName);
-
-    //reset this variable. we need to set this only if there is a change in typing state.
-    gSendTypingEvent = 0;
-
-    gSendNonEmptyEvent = 1;
-  }
-
-  if (gTypingPref) {
-    gEditorLength = editor.textLength;
-    if (gEditorLength == 0) {
-      aimIM().SetInputStateFlag(gTypingEnum.None, screenName);
-      gSendTypingEvent = 1;
-      gSendNonEmptyEvent = 0;
-    }
-    else {
-      window.clearTimeout(gTypingTimeoutid);
-      gTypingTimeoutid = window.setTimeout('CheckTypingState()', 5000);
-    }
-  }
-
+function composeKeyPress(event){
   if (event.keyCode == 46 || event.keyCode == 8)
   {
     /* If user hits backspace or delete key, check if the document will be emptied*/
      checkToDisable();
      return;
   }
-    
+        
   // This is how it really should be for control enter 
   // if ((event.ctrlKey) && (event.keyCode == 13))
   // Temporary hack since the above fails. Currently this condition is met by both control-enter 
@@ -359,18 +298,18 @@ function composeKeyPress(event)
   {
      event.preventBubble();
      event.preventDefault();
-     if (!editor.documentIsEmpty)
+     if (!window.editorShell.documentIsEmpty)
        window.setTimeout('AimIMCmdSend()', 1, true); 
      return false;
    }
    if ((event.keyCode == 13) || (event.keyCode == 10)){ 
-      if (event.shiftKey || editor.selection.isCollapsed == false)
+      if (event.shiftKey)
          return;
       if (SendOnEnter() == true) { 
          event.preventBubble();
          event.preventDefault();
          /* Make sure user is not sending a empty message */
-         if (!editor.documentIsEmpty)
+         if (!window.editorShell.documentIsEmpty)
             window.setTimeout('AimIMCmdSend(true)', 1, true); 
          return false; 
        } 
@@ -379,7 +318,7 @@ function composeKeyPress(event)
    } 
    if (event.keyCode == 9) {
     if (OnTab() == true) { 
-      if (!editor.documentIsEmpty) {
+      if (!window.editorShell.documentIsEmpty) {
         document.getElementById('btnSend').focus();
         FocusSend();
        }
@@ -393,7 +332,7 @@ function composeKeyPress(event)
            theScreenNameField.focus();
         }
         if(theWindowMode == "Bound") {
-          top.document.getElementById("LogWnd").contentWindow.focus();
+          top.frames['LogWnd'].focus();
         }
        }
       event.preventDefault();
@@ -407,11 +346,7 @@ function composeKeyPress(event)
 
 function checkToDisable()
 {
-  var editor = GetCurrentEditor();
-  if (!editor)
-    return;
-
-  var origLength = editor.textLength;
+  var origLength=window.editorShell.documentLength;
   /* If there is only one element in the document and the user chooses to delete that element,
 then the document will be emptied. Disable send button in this case */      
   if (origLength == 1)
@@ -419,7 +354,7 @@ then the document will be emptied. Disable send button in this case */
     DisableSendButton();
     return;
   }
-  var selection = editor.selection;
+  var selection=editorShell.editorSelection;
   if (!selection)
     return;
   var tempString=new String(selection);
@@ -442,19 +377,19 @@ function composeMenuPaste()
   if (isOnline) 
     EnableSendButton();   
 }
-function composeSendButtonUpdate()
-{
-  // Give time for editor to update the document after mouse events
-  setTimeout("checkcomposeSend()", 5);
+function composeSendButtonUpdate() {
+  // Give time for editorShell to update the document after mosue events
+  setTimeout("checkcomposeSend()", 300);
 }
 
 function checkcomposeSend()
 {
-  var editor = GetCurrentEditor();
-  if (editor && editor.textLength > 0)
+
+  if (!window.editorShell.documentIsEmpty)
      EnableSendButton();
   else 
      DisableSendButton();
+   
 }
 
 function DoNothing()
@@ -485,19 +420,19 @@ function StartConversation()
         screenName= args.ScreenName;
     else
         screenName = "";
-
+    
     if(args.DisplayName)
-        displayName= args.DisplayName;
+      displayName= args.DisplayName;
     else
-        displayName = "";
+      displayName = "";
 
     if(args.Message) {
         message= args.Message;
-    }
+  }
     else
         message = "";
-
-    if ( args.Mode == "KnockKnock" ) {
+    
+  if ( args.Mode == "KnockKnock" ) {
     var session = aimSession();
     if ( session ) {
       session.AddKnockKnockAccept(screenName);
@@ -513,24 +448,26 @@ function StartConversation()
   //top.imObject.editorHasFocus = true;   /* XXX */
 
   var editorElement = document.getElementById("ComposeWnd");
-  if (!editorElement)
+  if (!editorElement) {
     return;
+  }
+  
+  var editorShell = editorElement.editorShell;
+  if (!editorShell) {
+    return;
+  }
 
-  EditorSharedStartup();
-  var commandManager = GetCurrentCommandManager();
+  if(editorShell) {     
+    // save the editorShell in the window. The editor JS expects to find it there.
+    editorShell.RegisterDocumentStateListener( IMDocumentStateListener );
+    window.editorShell = editorShell;
 
-  try {
-    commandManager.addCommandObserver(gIMEditorStateObserver, "obs_documentCreated");
-    commandManager.addCommandObserver(gIMEditorStateObserver, "cmd_setDocumentModified");
-
-    // Load empty page to create the editor
-    editorElement.webNavigation.loadURI("about:blank", // uri string
-                         0,                            // load flags
-                         null,                         // referrer
-                         null,                         // post-data stream
-                         null);
-  } catch (e) {
-    dump(" Failed to startup editor: "+e+"\n");
+    window.editorShell.editorType = "html";
+    window.editorShell.webShellWindow = window;
+    window.editorShell.contentWindow = window._content;
+    
+    window.editorShell.LoadUrl("about:blank");
+    EditorSharedStartup();
   }
 
   top.document.getElementById("fldScreenName").value = screenName;
@@ -574,7 +511,19 @@ function StartConversation()
     }
   }
   
+var DocumentStateListener =
+{
+  NotifyDocumentCreated: function()
+  {
+    //see bugzilla bug 112960 for why we have a timeout call
     setTimeout("setStyles()", 100);
+  },
+  NotifyDocumentWillBeDestroyed: function() {},
+  NotifyDocumentStateChanged:function( isNowDirty ) {}
+};
+
+  // add a listener to be called when the editor is really done loading
+  editorShell.RegisterDocumentStateListener( DocumentStateListener );
 
 /*
   var theLogNode = top.frames['LogWnd'];
@@ -586,93 +535,9 @@ function StartConversation()
   theLogHead.appendChild(docFrag);
 */
 
-  if (commandManager && isIcq()) {//ICQ
-   unregisterCommand(commandManager, "cmd_indent");
-   unregisterCommand(commandManager, "cmd_outdent");
-   unregisterCommand(commandManager, "cmd_bold");
-   unregisterCommand(commandManager, "cmd_italic");
-   unregisterCommand(commandManager, "cmd_underline");
-   unregisterCommand(commandManager, "cmd_tt");
-   unregisterCommand(commandManager, "cmd_strikethrough");
-   unregisterCommand(commandManager, "cmd_superscript");
-   unregisterCommand(commandManager, "cmd_subscript");
-   unregisterCommand(commandManager, "cmd_nobreak");
-   unregisterCommand(commandManager, "cmd_em");
-   unregisterCommand(commandManager, "cmd_strong");
-   unregisterCommand(commandManager, "cmd_cite");
-   unregisterCommand(commandManager, "cmd_abbr");
-   unregisterCommand(commandManager, "cmd_acronym");
-   unregisterCommand(commandManager, "cmd_code");
-   unregisterCommand(commandManager, "cmd_samp");
-   unregisterCommand(commandManager, "cmd_var");
-   unregisterCommand(commandManager, "cmd_ol");
-   unregisterCommand(commandManager, "cmd_ul");
-   unregisterCommand(commandManager, "cmd_dt");
-   unregisterCommand(commandManager, "cmd_dd");
-   unregisterCommand(commandManager, "cmd_removeList");
-   unregisterCommand(commandManager, "cmd_paragraphState");
-   unregisterCommand(commandManager, "cmd_fontFace");
-   unregisterCommand(commandManager, "cmd_fontColor");
-   unregisterCommand(commandManager, "cmd_backgroundColor");
-   unregisterCommand(commandManager, "cmd_highlight");
-   unregisterCommand(commandManager, "cmd_align");
-   unregisterCommand(commandManager, "cmd_removeStyles");
-   unregisterCommand(commandManager, "cmd_increaseFont");
-   unregisterCommand(commandManager, "cmd_decreaseFont");
-  }
+  return false;
 }
 
-/*
- * gIMEditorStateObserver is the listener which the IM compose window uses.
- * NotifyDocumentCreated gets called by the editor after the editor is created and
- *    document is built.
- * If there is any IM message from the input arguments, then that is added 
- *    to the compose window and the send button is enabled.
-*/
-var gIMEditorStateObserver =
-{ 
-  observe: function(aSubject, aTopic, aData)
-  {
-    var editor = GetCurrentEditor();
-    var commandManager = GetCurrentCommandManager();
-    if (!editor || !commandManager || commandManager != aSubject)
-      return;
-    
-    switch (aTopic)
-    {
-      case "obs_documentCreated":
-        //XXX Do we need an init call to C++ here?
-        //gMsgCompose.initEditor(editor, window.content);
-
-        setTimeout("sendButtonListeners()",100);
-        var nsIPlaintextEditor = Components.interfaces.nsIPlaintextEditor;
-        editor.flags |= nsIPlaintextEditor.eEditorNoCSSMask;
-
-        if (message)
-        {
-          editor.insertHTML(message);
-          EnableSendButton();
-        }
-
-        //see bugzilla bug 112960 for why we have a timeout call
-        setTimeout("setStyles()", 100);
-        break;
-
-      case "cmd_setDocumentModified":
-        var commandParams = newCommandParams();
-        if (commandParams)
-        {
-          commandManager.getCommandState("cmd_setDocumentModified", commandParams);
-          if (commandParams.getBooleanValue("state_attribute"))
-            EnableSendButton();
-        }
-        
-        break;
-    }
-  }
-}
-
-
 function DoFocusAdjust()
 {
   var ScrElement=document.getElementById("fldScreenName");
@@ -695,22 +560,19 @@ function AimIMOnWndUnload()
   var pPAimIM = aimPIMObject();
   if(pPAimIM)
     pPAimIM.OnWindowUnload(screenName, top);
-
-  // send the none input state flag
-  aimIM().SetInputStateFlag(gTypingEnum.None, screenName);
-
 }
 
-function AimIMCmdSend(strip)
+function AimIMCmdSend( strip )
 {
   AimIMSetFormAction(true);
   var isOnline= aimSession().IsOnline();
-  if (!isOnline) {
-    if (!isIcq())
+  if (isOnline == false) {
+    if (isIcq() == false) {
       aimErrorBox(aimString("msg.LogInToSendIM"));
-    else
+    }
+    else {
       aimErrorBox(aimString("msg.LogInToSendIM_ICQ"));
-
+    }
     toOpenWindowByType('Aim:AimApp', 'chrome://aim/content/App.xul');
     return false;
   }
@@ -718,63 +580,41 @@ function AimIMCmdSend(strip)
   var displayName = AimIMGetFormDisplayName();
 
   if ( !screenName || screenName == "" ) {
-    if (isIcq() == false) {
-      aimErrorBox(aimString("msg.EmptyScreenName"));
-      }
-    else {
-      aimErrorBox(aimString("msg.EmptyScreenName_ICQ"));
-      }
-
+    aimErrorBox(aimString("msg.EmptyScreenName"));
     top.document.getElementById("fldScreenName").focus();
     return false;
   }
-  
-  if (firstSend) {
-    var cp = new String(screenName);
-    if (!IsValidChar(cp)){
-      // Cannot contain invalid characters 
-      aimErrorBox(aimString("msg.InvalidScreenName"));
-      top.document.getElementById("fldScreenName").focus();
-      return false;
-    }
-  }
-
-
-  if(!AimIMIsBound() ) {
+  if(false == AimIMIsBound() ) {
     // XXX Should be handled when blur works.
     AimIMSetFormScreenName(top.document.getElementById("fldScreenName").value, top.document.getElementById("fldDisplayName").value);
     screenName = AimIMGetFormScreenName();
+
+  }
+  if (top.editorShell.documentLength >1024)
+  {
+    aimErrorBox(aimString("msg.BigIM").replace(/%BigBy%/, ""+(top.editorShell.documentLength-1024)));
+    return;
   }
   
   var bodyText;
   var plainBodyText = null;
-  var editor = GetCurrentEditor();
-  if (!editor)
-    return;
-
-  if (aimPrefsManager().GetSessionType()  == 2) {//ICQ
-    plainBodyText = editor.outputToString("text/plain", 2);
+  var isUnification=getPreaknessFlag();
+  if ((aimPrefsManager().GetSessionType()  == 2) || isUnification) {//ICQ
+    plainBodyText = top.editorShell.GetContentsAs("text/plain", 2);
     // because of bug in dom text serializer, last call inserts additional new line at the end
     // we need to eliminate it
     plainBodyText = plainBodyText.replace(/\r\n$|\r$|\n$/, "");
-    if (plainBodyText) {
-      var icqMsgLength = plainBodyText.length;
-      if (icqMsgLength > 1024) {
-        aimErrorBox(aimString("msg.BigIM").replace(/%BigBy%/, ""+ (icqMsgLength-1024)));
-        return;
-      }
-    }
   }
 
-  bodyText = "<html>" + editor.outputToString("text/html", 8 + 4) + "</html>";
+  bodyText = "<html>" + top.editorShell.GetContentsAs("text/html", 8 + 4) + "</html>";
+
+  /* if user hit return, strip out the BR that was added */
 
   bodyText = bodyText.replace(/<\/span><\/span>/g,  " ");
   bodyText = bodyText.replace(/<span class="moz-smiley-s[0-9][0-9]?"><span>/g, " ");
-  bodyText = bodyText.replace(/<br><br>/gi, "<br>");
 
-  if (strip) {
-    // If thereis a close tag right after the break then this wasn't likely entered by hand.
-    bodyText = bodyText.replace(/<br><\//gi, "<\/");
+  if ( strip == true ) {
+    bodyText = bodyText.replace(/<br>/gi, "");
   }
 
   bodyText = bodyText.replace(/\r\n|\r|\n/g, " ");
@@ -782,6 +622,7 @@ function AimIMCmdSend(strip)
   bodyText = bodyText.replace(/<\/big>/gi, "<\/font>");
   bodyText = bodyText.replace(/<small>/gi, "<font size=\"-1\">");
   bodyText = bodyText.replace(/<\/small>/gi, "<\/font>");
+  bodyText = bodyText.replace(/<br><br>/gi, "<br>");
   bodyText = bodyText.replace(/<br><\/body>/i, "<\/body>");
   bodyText = bodyText.replace(/\u00a0/gi, " ");
 
@@ -792,15 +633,7 @@ function AimIMCmdSend(strip)
     bodyText = bodyText.replace(/<\/body>/gi, "<\/font><\/body>");
   }
 
-  if (bodyText) {
-    var imMsgLength = bodyText.length;
-    if (imMsgLength > 1024) {
-      aimErrorBox(aimString("msg.BigIM").replace(/%BigBy%/, ""+ (imMsgLength-1024)));
-      return;
-    }
-  }
-
-  if (AimOnlineAway())
+  if ( AimOnlineAway() )
     ComeBack();   // if away, come back
 
   if (firstSend) {
@@ -809,21 +642,16 @@ function AimIMCmdSend(strip)
     aimIM().SetIMWndIcon(screenName);
     firstSend = 0;
   }
-
-  aimIM().SetInputStateFlag(gTypingEnum.None, screenName);
-  gSendNonEmptyEvent = 0;
-
   aimPIMSendIM(top, screenName, bodyText, plainBodyText);
 
   var session = aimSession();
   if ( session )
     session.AddKnockKnockAccept( screenName );
   
-  gTypingPref = checkTypingPref();
-  editor.selectAll();
+  top.editorShell.SelectAll();
   getStyles();
-  editor.deleteSelection(null);
-  /* After the contents have been emptied, disable the send button*/
+  top.editorShell.DeleteSelection(null);
+        /* After the contents have been emptied, disable the send button*/
   DisableSendButton();
   setStyles();
 
@@ -866,7 +694,6 @@ function AimIMGetFormScreenName()
   return myScreenName;
 }
 
-
 function AimIMGetFormDisplayName()
 {
     var myDisplayName = top.document.getElementById("fldDisplayName").value;
@@ -875,8 +702,7 @@ function AimIMGetFormDisplayName()
         myDisplayName = args.DisplayName;
   return myDisplayName;
 }
-
-
+ 
 function AimIMRefreshScreenName()
 {
   AimIMSetFormScreenName(top.document.getElementById('fldScreenName').value, top.document.getElementById('fldDisplayName').value);
@@ -926,7 +752,7 @@ function AimIMSetFormScreenName(screenName, displayName)
     }
     else {
       if ((displayName == "") || (!displayName))
-        title = aimString("im.title.Bound").replace(/%ScreenName%/, screenName);
+      title = aimString("im.title.Bound").replace(/%ScreenName%/, screenName);
       else
         title = aimString("im.title.Bound").replace(/%ScreenName%/, displayName+", "+ screenName);
     }
@@ -1086,13 +912,11 @@ function OnTab()
 function EnableSendButton()
 {
   top.document.getElementById("btnSend").setAttribute("disabled", "false");
-  top.document.getElementById("cmd_Send").setAttribute("disabled", "false");
 }
 
 function DisableSendButton()
 {
   top.document.getElementById("btnSend").setAttribute("disabled", "true");
-  top.document.getElementById("cmd_Send").setAttribute("disabled", "true");
   UnFocusSend();
 } 
 
@@ -1132,6 +956,7 @@ function sendButtonListeners()
     bbox.addEventListener("mousedown", composeSendButtonUpdate, true);
     bbox.addEventListener("mouseup", composeSendButtonUpdate, true);
     bbox.addEventListener("dragdrop", composeSendButtonUpdate, true);
+   
   }
 
 }
@@ -1199,8 +1024,8 @@ function LoadBuddyIcon(screenname)
     return;
   }
 
-  var fileHandler = GetFileHandler();
-  var bifileurl = fileHandler.getURLSpecFromFile(biPath);
+  var ioService = GetIOService();
+  var bifileurl = ioService.getURLSpecFromFile(biPath);
     
   var currentTime = new Date().getTime();
   var BIfield = top.document.getElementById("BuddyIcon");
@@ -1209,13 +1034,12 @@ function LoadBuddyIcon(screenname)
 }
 
 
-function GetFileHandler()
+function GetIOService()
 {
   var IOService = Components.classes["@mozilla.org/network/io-service;1"]
                .getService(Components.interfaces.nsIIOService);
 
-  return IOService.getProtocolHandler("file")
-                  .QueryInterface(Components.interfaces.nsIFileProtocolHandler);
+  return IOService;
 }
 
 function updateCurrentComposeWindow()
@@ -1237,42 +1061,19 @@ function updateCurrentComposeWindow()
     document.getElementById('tbAddBuddy').setAttribute('label', icqval);
     icqval=document.getElementById('tbAddBuddy').getAttribute('icqtooltip','value');
     document.getElementById('tbAddBuddy').setAttribute('tooltiptext', icqval);
-    icqval=document.getElementById('btnSend').getAttribute('icqtooltip','value');
-    document.getElementById('btnSend').setAttribute('tooltiptext', icqval);
     icqval=document.getElementById('tbBlock').getAttribute('icqlabel','value');
     document.getElementById('tbBlock').setAttribute('label', icqval);
     icqval=document.getElementById('tbBlock').getAttribute('icqtooltip','value');
     document.getElementById('tbBlock').setAttribute('tooltiptext', icqval);
     document.getElementById('formatMenu').setAttribute('hidden', true);
-    document.getElementById('insertMenu').setAttribute('hidden', true);
+    icqval=document.getElementById('btnSend').getAttribute('icqtooltip','value');
+    document.getElementById('btnSend').setAttribute('tooltiptext', icqval);
   }
-}
-
-function checkTypingPref()
-{
-  var prefmask = aimFeedbagManager().GetBuddyPrefs();
-  if (prefmask & Components.interfaces.nsAimBuddyPrefs.DiscloseTyping)
-    return true;
   else
-    return false;
-}
-
-function CheckTypingState()
-{
-  var editor = GetCurrentEditor();
-  if (!editor)
-    return;
-  var newLength = editor.textLength;
-  //SURESH: This is bit hacky. My guess is something is wrong with the way editor returns for textLength.
-  //gEditorLength is off by 1 when you type something or backspace. :(
-  if (gSendNonEmptyEvent && newLength > 0 && ((newLength == gEditorLength + 1) || (newLength == gEditorLength - 1))) {
-    var screenName = AimIMGetFormScreenName();
-    aimIM().SetInputStateFlag(gTypingEnum.NotEmpty, screenName);
-    gSendTypingEvent = 1;
-
-    //reset the non empty typing event, so that it is not sent for every key press
-    gSendNonEmptyEvent = 0;
+  {
+    // App is aim, hide icq disp stuff
+    document.getElementById('icqDisplayFields').setAttribute('hidden', true);
+    document.getElementById('fldDisplayName').setAttribute('hidden', true);
   }
-
-
 }
+
