@@ -14,7 +14,7 @@ function AimWindowLoad2(topWindow)
 	//tabObj.click();
 
 	var tabPanel = topWindow.frames["AimSidebarPanel"].document.getElementById("OnlineOrgTabPanel");
-	tabPanel.setAttribute("index",1);
+	tabPanel.setAttribute("selectedIndex",1);
 
 	var parentState = topWindow.document.getElementById("AimSidebarState");
 	if(!parentState)
