@@ -26,7 +26,12 @@ var CachedAimRDFService = null;
 var CachedAimRDF  = null;
 var CachedSessionType= null;
 var CachedUserConnection = null;
-var CachedFileProtocolHandler = null;
+var disp=new Object();
+var cur_val=0;
+var cur_name=null;
+
+
+
 
 /* Various IDL that represent enumerated types */
 var CachedAimAuthorizerState = null;
@@ -34,23 +39,6 @@ var CachedAimInsertionStyles = null;
 var CachedAimPrivacyModes = null;
 var CachedAimTalkAudioMode = null;
 
-/*
- * Function: aimFileProtocolHandler()
- * Arguments: None
- * Return: the cached file:// protocol handler
- */
-function aimFileProtocolHandler()
-{
-  try {
-    if (CachedFileProtocolHandler == null) {
-      var ios = Components.classes["@mozilla.org/network/io-service;1"]
-                          .getService(Components.interfaces.nsIIOService);
-      CachedFileProtocolHandler = ios.getProtocolHandler("file")
-                                     .QueryInterface(Components.interfaces.nsIFileProtocolHandler);
-    }
-  } catch (e) {};
-  return CachedFileProtocolHandler;
-}
 
 /*
  * Function: aimRDFServiceClass()
@@ -641,7 +629,7 @@ function createInstance( contractid, iidName ) {
 function cmdFileSave()
 {
   var answer;
-  var wind = top.document.getElementById("LogWnd").contentWindow;
+  var wind = top.frames["LogWnd"];
   if ( wind ) {
 	  myhead = wind.document.getElementsByTagName("HEAD").item(0);
 		if (myhead == null) {
@@ -664,16 +652,15 @@ function cmdFileSave()
     // XXX i18n
     fp.init(window, aimString( "title.saveconversation" ),  nsIFilePicker.modeSave);
     fp.appendFilters(nsIFilePicker.filterHTML | nsIFilePicker.filterAll );
-    fp.defaultString = aimString("log.defaultfilename") + ".html";
-    var returnCode = fp.show();
+		var returnCode = fp.show();
     if (returnCode == nsIFilePicker.returnOK || returnCode == nsIFilePicker.returnReplace) {
-      var pPAimIM = aimPIMObject();
-      if (pPAimIM)
-      {
+		  var pPAimIM = aimPIMObject();
+			if (pPAimIM) {
         pPAimIM.SaveConversation(fp.file.path, answer);
-      }
+			}
     }
-  } catch (ex) { }
+  } catch (ex) {
+		           }
 }
 
 /*
@@ -701,16 +688,16 @@ function cmdFilePrint(window)
 {
   switch(window) {
   case "im":
-          if (top.document.getElementById("LogWnd").contentWindow.document.documentElement.lastChild.firstChild != null) {
+          if (top.frames["LogWnd"].document.documentElement.lastChild.firstChild != null) {
             // print the contents of log window
-            top.document.getElementById("LogWnd").contentWindow.print();
+            top.frames["LogWnd"].print();
             return;
           }
           // No log window yet - print the compose window
-          NSPrint();
+          top.editorShell.Print();
           break;
   case "chat":
-          top.document.getElementById("LogWnd").contentWindow.print();
+          top.frames["LogWnd"].print();
           break;
   }
 }
@@ -851,9 +838,8 @@ function ComeBack()
 
 function AimtoOpenWindowByType( inType, uri )
 {
-  //var windowManager = Components.classes['@mozilla.org/rdf/datasource;1?name=window-mediator'].getService();
-  //var     windowManagerInterface = windowManager.QueryInterface( Components.interfaces.nsIWindowMediator);
-  var windowManagerInterface = Components.classes["@mozilla.org/appshell/window-mediator;1"].getService(Components.interfaces.nsIWindowMediator);
+  var windowManager = Components.classes['@mozilla.org/rdf/datasource;1?name=window-mediator'].getService();
+  var     windowManagerInterface = windowManager.QueryInterface( Components.interfaces.nsIWindowMediator);
   var topWindow = windowManagerInterface.getMostRecentWindow( inType );
   if ( topWindow ) {
     topWindow.focus();
@@ -873,11 +859,14 @@ function AimtoOpenWindowByType( inType, uri )
 
 function aimGlobalCmdHelp()
 {
-  if (isIcq())
-    openHelp("icq");
-  else
-    openHelp("im");
+   if (isIcq()) {
+       AimtoOpenWindowByType("help:icq","chrome://help/content/help.xul?icq"); 
+   }
+   else {
+  		AimtoOpenWindowByType("help:im","chrome://help/content/help.xul?im"); 
+   }
 }
+	
 
 /*
  * Function: AimgoClickThrobber(urlPref)
@@ -909,10 +898,10 @@ function AimgoClickThrobber(urlPref)
  * parameter it will be further identified. So e.g. in case of away message, the file will be named 
  * as <screenname><chg_name>.rdf. If this file cannot be created from the user's profile, then default 
  * profile file is copied over and this will now be called after the session's screen name and chg_name param. 
- * The exact identity and location of this file is then obtained  by using nsIFileProtocolHandler and 
+ * The exact identity and location of this file is then obtained  by using nsIFileURL and 
  * the unique url gets returned.
 */
-function GetRdfFileUrl(def_name, chg_name, skipScreenName)
+function GetRdfFileUrl(def_name, chg_name)
 {                                                                               
 	var directoryService  =  Components.classes["@mozilla.org/file/directory_service;1"].getService(Components.interfaces.nsIProperties);
 	var userProfile = directoryService.get("ProfD", Components.interfaces.nsIFile);
@@ -923,26 +912,23 @@ function GetRdfFileUrl(def_name, chg_name, skipScreenName)
 	defaultInviteFile.append(def_name);                                     
   var screenName = "";                                                
   myPref = aimPrefsManager();                                         
-  if ( myPref && !skipScreenName )
-  {                                                         
-    try {                                                           
-      screenName = myPref.GetCharPref( "aim.session.screenname" , null, false);
-    }
-    catch(e)
-    {                                                      
-      screenName = "";                                        
-    }
-  }   
-  if ( screenName != "" )
-  {                                               
-    screenName = screenName + ".";                                  
+  if ( myPref ) {                                                         
+	  try {                                                           
+			screenName = myPref.GetCharPref( "aim.session.screenname" , null, false);
+		  }
+	  catch(e) {                                                      
+	         screenName = "";                                        
+		       }
+	}   
+	if ( screenName != "" ) {                                               
+		screenName = screenName + ".";                                  
   }
-  else if(!skipScreenName)                                                   
+	else                                                            
   {
-    return;                                         
+	  return;                                         
   }
-  var InviteListFile = userProfile.clone();
-  InviteListFile.append(screenName+chg_name);                             
+	var InviteListFile = userProfile.clone();
+	InviteListFile.append(screenName+chg_name);                             
     if (!InviteListFile.exists()) {                                         
 		  try {
 			  defaultInviteFile.copyTo(userProfile,screenName+chg_name);     
@@ -954,9 +940,11 @@ function GetRdfFileUrl(def_name, chg_name, skipScreenName)
       if (!InviteListFile.exists())    {
         // Something is wrong - This should never happen
         return;
-      }                             
+      }                               
     }                                                                       
-    return aimFileProtocolHandler().getURLSpecFromFile(InviteListFile);
+  var InviteFileURL = Components.classes["@mozilla.org/network/standard-url;1"].createInstance(Components.interfaces.nsIFileURL);
+	InviteFileURL.file = InviteListFile;
+	return( InviteFileURL.spec );                                           
 }  
 
 /*
@@ -1054,18 +1042,18 @@ function getPrettyDateDiff(aDate2, aDate1)
   var dayDiff = Math.floor(diff / 86400);
   diff %= 86400;
   if (dayDiff > 0) {
-    pretty += dayDiff + " " + (dayDiff == 1 ? aimString("tooltip.day") : aimString("tooltip.days"));
+    pretty += dayDiff + " day" + (dayDiff == 1 ? "" : "s");
   }
    
   var hourDiff = Math.floor(diff / 3600);
   diff %= 3600;
   if (hourDiff > 0) {
-    pretty += (pretty.length > 0 ? ", " : "") + hourDiff + " " + (hourDiff == 1 ? aimString("tooltip.hour") : aimString("tooltip.hours"));
+    pretty += (pretty.length > 0 ? ", " : "") + hourDiff + " " + aimString("tooltip.hour") + (hourDiff == 1 ? "" : "s");
   }
    
   var minDiff = Math.floor(diff / 60);
   if (minDiff > 0) {
-    pretty += (pretty.length > 0 ? ", " : "") + minDiff + " " + (minDiff == 1 ? aimString("tooltip.minute") : aimString("tooltip.minutes"));
+    pretty += (pretty.length > 0 ? ", " : "") + minDiff + " " + aimString("tooltip.minute") + (minDiff == 1 ? "" : "s");
   }
    
   return pretty;
@@ -1203,23 +1191,6 @@ function getSelectedScreenName()
   return screenName;
 }
 
-
-function getGroupForScreenName()
-{
-  var tree = getSelectedTreeName();
-  var col = getSelectedTabName();
-  if (!tree || !col) return;
-  var groupName = null;
-  var currentIndex = tree.currentIndex;
-  if (currentIndex > 0) {
-    var parentIndex = tree.treeBoxObject.view.getParentIndex(currentIndex);
-    var parentResource = GetBuddyResource(tree, parentIndex);
-    groupName = GetBuddyAttribute(tree, parentResource, "Name");
-  }
-  return groupName;
-}
-
-
 /*
 * Name: checkInputEmail
 * Arguments: input email value 
@@ -1272,11 +1243,11 @@ function setConnectionInfo (connectionName, aClient, screenName)
         curSession = 0;
     else // ICQ
         curSession = 2;
-
-    	
+       
+ 
 
     manPref = aimPrefsManager();
-            
+ 
     var Host           = manPref.GetCharPrefEdit ("aim.session.host",           null, 2, "", curSession);
     var Port           = manPref.GetIntPrefEdit  ("aim.session.port",           null, 2, "", curSession);
     var ProxyHost      = manPref.GetCharPrefEdit ("aim.session.proxyhost",      null, 2, "", curSession);
@@ -1292,61 +1263,61 @@ dump("ProxyUser=" + ProxyUser + " ProxyPassword=" + ProxyPassword + " ProxyProto
 dump("useProxy=" + useProxy + " ConnectionType=" + ConnectionType + "\n");
 
 
-        if (aClient == "im") { // internal session
+    if (aClient == "im") { // internal session
 
         manPref.SetIntPrefEdit  ("aim.internal.intsessiontype",  curSession,    
-                                     null, 1, "", -1);
+                                 null, 1, "", -1);
         manPref.SetWCharPrefEdit("aim.internal.intname",         connectionName, 
-                                     null, 1, "", -1);
+                                 null, 1, "", -1);
         manPref.SetCharPrefEdit("aim.internal.inthost",             Host,           
-                                     null, 1, "", -1);
+                                 null, 1, "", -1);                  
         manPref.SetIntPrefEdit  ("aim.internal.intport",            Port,           
-                                     null, 1, "", -1);
+                                 null, 1, "", -1);                  
         manPref.SetCharPrefEdit("aim.internal.intproxyhost",        ProxyHost,      
-                                     null, 1, "", -1);
+                                 null, 1, "", -1);                  
         manPref.SetIntPrefEdit  ("aim.internal.intproxyport",       ProxyPort,      
-                                     null, 1, "", -1);
+                                 null, 1, "", -1);                  
         manPref.SetWCharPrefEdit("aim.internal.intproxyuser",       ProxyUser,      
-                                     null, 1, "", -1);
+                                 null, 1, "", -1);                  
         manPref.SetWCharPrefEdit("aim.internal.intproxypassword",   ProxyPassword,  
-                                     null, 1, "", -1);
+                                 null, 1, "", -1);                  
         manPref.SetIntPrefEdit  ("aim.internal.intproxyprotocol",   ProxyProtocol,  
-                                     null, 1, "", -1);
-            manPref.SetBoolPrefEdit ("aim.internal.intisproxy",      useProxy,                 
-                                     null, 1, "", -1);
+                                 null, 1, "", -1);
+        manPref.SetBoolPrefEdit ("aim.internal.intisproxy",         useProxy,                 
+                                 null, 1, "", -1);
         manPref.SetIntPrefEdit  ("aim.internal.intconnectiontype",  ConnectionType,                 
-                                     null, 1, "", -1);                                           
-        }
-        else { //external session
+                                 null, 1, "", -1);                                           
+    }
+    else { //external session
 
         manPref.SetIntPrefEdit  ("aim.internal.extsessiontype",  curSession,    
-                                     null, 1, "", -1);
+                                 null, 1, "", -1);
         manPref.SetWCharPrefEdit("aim.internal.extname",         connectionName, 
-                                     null, 1, "", -1);
+                                 null, 1, "", -1);
         manPref.SetCharPrefEdit("aim.internal.exthost",           Host,           
-                                     null, 1, "", -1);
+                                 null, 1, "", -1);
         manPref.SetIntPrefEdit  ("aim.internal.extport",          Port,           
-                                     null, 1, "", -1);
+                                 null, 1, "", -1);
         manPref.SetCharPrefEdit("aim.internal.extproxyhost",      ProxyHost,      
-                                     null, 1, "", -1);
+                                 null, 1, "", -1);
         manPref.SetIntPrefEdit  ("aim.internal.extproxyport",     ProxyPort,      
-                                     null, 1, "", -1);
+                                 null, 1, "", -1);
         manPref.SetWCharPrefEdit("aim.internal.extproxyuser",     ProxyUser,      
-                                     null, 1, "", -1);
+                                 null, 1, "", -1);
         manPref.SetWCharPrefEdit("aim.internal.extproxypassword", ProxyPassword,  
-                                     null, 1, "", -1);
+                                 null, 1, "", -1);
         manPref.SetIntPrefEdit  ("aim.internal.extproxyprotocol", ProxyProtocol,  
-                                     null, 1, "", -1);
-            manPref.SetBoolPrefEdit ("aim.internal.extisproxy",      useProxy,   
-                                     null, 1, "", -1);  
+                                 null, 1, "", -1);
+        manPref.SetBoolPrefEdit ("aim.internal.extisproxy",       useProxy,   
+                                 null, 1, "", -1);  
         manPref.SetIntPrefEdit  ("aim.internal.extconnectiontype", ConnectionType,   
-                                     null, 1, "", -1);  
-        }
-
-        return true;
-
+                                 null, 1, "", -1);  
     }
 
+    return true;
+    
+}
+
 
 /*
  * Function: GetPanelSessionType 
@@ -1408,8 +1379,12 @@ function CopynGetUrl (def_name, chg_name)
       UserConnections.append(chg_name);   
 
     }  
+	
+    var UserConnectionsURL = Components.classes["@mozilla.org/network/standard-url;1"].createInstance(Components.interfaces.nsIFileURL);
+	UserConnectionsURL.file = UserConnections;
+
+	return( UserConnectionsURL.spec );
 
-    return aimFileProtocolHandler().getURLSpecFromFile(UserConnections);
 }
 
 /*
@@ -1500,7 +1475,7 @@ function IsServiceCorrect (curSN, curConnName)
        else
         aimErrorBox(aimString("msgICQ.wrongsrv").replace(/%ScreenName%/, '"' + curSN + '"'));
 
-        return false;
+       return false;
    }
 
       
@@ -1537,7 +1512,7 @@ function openRegisterLink(sessionID)
     }
   else
     {
-      regLink = aimRegionString("icq.register.url");
+      regLink = aimString("icq.register.url");
       openTopWin(regLink);  
       return;
     }
@@ -1554,22 +1529,23 @@ function openRegisterLink(sessionID)
  * server side search for Machv.
  *
  * Author: Prassanna 4/29/2002
- */
-
-
+*/
+  
+ 
 function cmdIcqSearch()
 {
-   var url=aimRegionString("icq.search.url");
+   var url=aimString("icq.search.url");
    if (window.opener) {
        // From add buddy modal dialog
-       window.opener.openDialog("chrome://navigator/content/navigator.xul", "_blank","modal=no,chrome,all,dialog=no", url);
+       window.opener.openDialog("chrome://navigator/content/navigator.xul", "_blank","modal=no,chrome,chrome,extrachrome,menubar,resizable,scrollbars,status,toolbar", url);
        return;
        //Since we have a modal window opening some other window (yuk!), this opener stuff is there
       // Clean this up post-Machv when real icq search is supported
    }
-   openDialog("chrome://navigator/content/navigator.xul", "_blank","modal=no,chrome,all,dialog=no", url);
+   openDialog("chrome://navigator/content/navigator.xul", "_blank","modal=no,chrome,chrome,extrachrome,menubar,resizable,scrollbars,status,toolbar", url);
 }
 
+
 /*
  * Function: openPrefWindow
  * Arguments: none
@@ -1580,11 +1556,19 @@ function cmdIcqSearch()
 function openPrefWindow()
 {
   if (isIcq())
-    goPreferences('instantmessenger', 'chrome://aim/content/pref-Icq_icq.xul','icq');
+    goPreferences('icq', 'chrome://aim/content/pref-Icq_icq.xul','icq');
   else
     goPreferences('instantmessenger', 'chrome://aim/content/pref-IM_instantmessage.xul','instantmessenger');
 }
 
+/* Selects the given index in the buddy list */
+function SelectIndex(index)
+{
+  var tree = getSelectedTreeName();
+  var treeselection = tree.treeBoxObject.selection;
+  treeselection.select(index);
+}
+
 
 /*
  * Function: cachedUserConnection
@@ -1601,24 +1585,6 @@ function cachedUserConnection()
   } catch (e) {}; 
   return CachedUserConnection;
 }
-      
-function getSelectedDisplayName()
-{
-  var tree = getSelectedTreeName();
-  var col = getSelectedTabName();
-  if (!tree || !col) return;
-  var displayName = null;
-  var currentIndex = tree.currentIndex;
-  if (currentIndex > 0) {
-    var isContainer = tree.treeBoxObject.view.isContainer(currentIndex);
-    //if it is a container (groups or Offline group) return null
-    if (!isContainer) {
-      var buddyResource = GetBuddyResource(tree, currentIndex);
-      var displayName = GetBuddyAttribute(tree, buddyResource, "Name");
-    }
-  }
-  return displayName;
-}
 
 /* Selects the given index in the buddy list */
 function SelectIndex(index)
@@ -1630,76 +1596,6 @@ function SelectIndex(index)
   }
 }
 
-function openMailCompose(emailaddresses)
-{
-  var msgComposeType = Components.interfaces.nsIMsgCompType;
-  var msgComposFormat = Components.interfaces.nsIMsgCompFormat;
-  var msgComposeService = Components.classes["@mozilla.org/messengercompose;1"].getService();
-  msgComposeService = msgComposeService.QueryInterface(Components.interfaces.nsIMsgComposeService);
-
-  var params = Components.classes["@mozilla.org/messengercompose/composeparams;1"].createInstance(Components.interfaces.nsIMsgComposeParams);
-  if (params)
-  {
-    params.type = msgComposeType.New;
-    params.format = msgComposFormat.Default;
-    var composeFields = Components.classes["@mozilla.org/messengercompose/composefields;1"].createInstance(Components.interfaces.nsIMsgCompFields);
-    if (composeFields)
-    {
-      composeFields.to = emailaddresses;
-      params.composeFields = composeFields;
-      msgComposeService.OpenComposeWindowWithParams(null, params);
-    }
-  }
-}
-
-function sendfile(screenName) {
-  inviteArgsObj = {
-    inviteProposalScreenName: screenName,
-    inviteProposalObj: null,
-    inviteToExistingWindow: false,
-    inviteMode: 'outgoingfile'
-  }
-  window.openDialog('chrome://aim/content/sendfile.xul','_blank','chrome,all,dialog=no',inviteArgsObj);
-}
-
-
-/*
- * Function: isValidChar
- * Arguments: string
- * Return: boolean
- * Description: Checks for invalid characters for buddynames. Except for alphanumeric chars, digits, 
- * comma, colon, underscore and forward slash, other special chars are invalid.
- * Author: Prassanna<prass@netscape.com> 
-*/
-
-function IsValidChar(cp)
-{
-  var c;
-  var j;
-  for (j=0; j < cp.length; j++)
-  {
-    c= cp.charCodeAt(j);
-    if ( ((c > 32) &&  (c < 44)) || ((c > 57) &&  (c < 64)) || ((c > 90) &&  (c < 95)) || (c == 96) || c > 122 )
-      return false;
-  }  
-  return true;
-}
-
-
-function IsValidLength(screenName)
-{
-  var nLen;
-  if ((!screenName) || (screenName == null) || (screenName == ''))
-  {
-    return false;
-  }
-  nLen = screenName.length;
-  if (nLen > 16 || nLen < 3) {
-    return false;
-  }
-  return true;
-}
-
 function getPreaknessFlag()
 {
   var myaimSession = aimSession();
@@ -1710,12 +1606,12 @@ function getPreaknessFlag()
     return false;
 }
 
-function IsIcqServiceUser(buddy)
+function aimBuddyIsIcq(screenName)
 {
-  var isAllDigits = false;
-  var cp = new String(buddy);
-  if ((cp.charCodeAt(0) > 47) && (cp.charCodeAt(0) < 58))
-  // Begins with a number - so icq
-    isAllDigits=true;
-  return isAllDigits;
+  var pIAimBuddy = aimBuddyManager();
+  if ( !screenName || screenName == "" )
+    return false;
+  if(pIAimBuddy)
+    return pIAimBuddy.IsBuddyInIcq(screenName);
 }
+
