@@ -42,31 +42,23 @@ nsContextMenu.prototype = {
     initItems : function () {
         this.initOnlineItems();
         this.initListSetupItems();
-        var supportmailim = aimPrefsManager().GetBoolPref("aim.session.supportmailim", null, false);
-        if (!supportmailim) {
-          this.setItemAttr("menu_switchview","hidden", "true");
-          this.setItemAttr("dispNameseparator","hidden", "true");
-          this.setItemAttr("context-editbuddyinfo","hidden", "true");
-          // this.setItemAttr("context-editdispname","hidden", "true");
-          // this.setItemAttr("context-updateemail","hidden", "true");
-          this.setItemAttr("preemailseperator","hidden", "true");
-          this.setItemAttr("context-sendemail","hidden", "true");
-          this.setItemAttr("context-checkemail","hidden", "true");
-          this.setItemAttr("gmiseparator","hidden", "true");
-        }
     },
 
     initOnlineItems : function () {
       this.showItem("context-getMemberInfo", this.onlineTab );
       this.showItem( "context-sendIM", this.onlineTab );
       this.showItem( "context-sendChat", this.onlineTab );
-      this.showItem("context-block");
-      this.showItem("blockseperator");
       if (this.screenName != "" && this.screenName != null) {
         this.setItemAttr("sendfileseparator","hidden", this.listSetupTab);
         this.showItem( "context-sendFile", this.onlineTab );
-        this.showItem("context-block", this.menu);
-        this.showItem("blockseperator", this.menu);
+        if (aimBuddyIsIcq(this.screenName))
+        {
+          this.showItem("context-editdispname", true);
+        }
+        else
+        {
+          this.showItem("context-editdispname", false);
+        }
         var isInList = new Object();
         aimBuddyManager().IsBuddyInAlertList(this.screenName, isInList);
         if ( isInList.value == false ) {
@@ -94,13 +86,11 @@ nsContextMenu.prototype = {
       else {
         //selected node has no screen name so it is a group
         this.setItemAttr("sendfileseparator","hidden", "true");
-        //this.setItemAttr("buddyalertseperator","hidden", "true");
-        this.setItemAttr("context-buddyAlert","hidden", "true");
-        this.setItemAttr("context-editbuddyAlert","hidden", "true");
         this.setItemAttr("buddyalertseperator","hidden", "true");
+        this.setItemAttr("context-buddyAlert","hidden", "true");
         this.showItem( "context-sendFile", false);
         this.showItem("sendfileseparator", false);
-        //this.showItem("context-editdispname", false);
+        this.showItem("context-editdispname", false);
         //this.showItem("context-sendemail", false);
         //this.showItem("context-checkemail", false);
         //this.showItem("context-updateemail", false);
@@ -240,29 +230,20 @@ nsContextMenu.prototype = {
 
     cmdContextBuddyAlert : function (isedit) {
       var screenName = getSelectedScreenName();
-      var groupName = getGroupForScreenName();
-      if (screenName && (screenName != null) && groupName && (groupName != null)) 
-      {
-        if (isedit == 1) 
-          window.openDialog('chrome://aim/content/AimBuddyAlert.xul','_blank','chrome,all,dialog=no', screenName, groupName, 1);
-        else
-          window.openDialog('chrome://aim/content/AimBuddyAlert.xul','_blank','chrome,all,dialog=no', screenName, groupName, null);
-      }	
+      if (screenName && (screenName != null)) {
+	if (isedit == 1) 
+          window.openDialog('chrome://aim/content/AimBuddyAlert.xul','_blank','chrome,all,dialog=no', screenName, 1);
+	else
+ 	  window.openDialog('chrome://aim/content/AimBuddyAlert.xul','_blank','chrome,all,dialog=no', screenName, null);
+     }	
     },
     
     cmdContextDelBuddyAlert : function () {
       var screenName = getSelectedScreenName();
-      var groupName = getGroupForScreenName();
-      if (screenName && (screenName != null) && groupName && (groupName != null))
-        aimBuddyManager().DeleteBuddyFromAlertList(screenName, groupName);
+      if (screenName && (screenName != null))
+        aimBuddyManager().DeleteBuddyFromAlertList(screenName);
     },
 
-    cmdContextBlockBuddy : function () {
-      var pIAimPrivacy = aimPrivacy();
-      if ( !pIAimPrivacy )
-        return false;
-      pIAimPrivacy.BlockUser(this.screenName);
-    },
 
 	//cmdContextEditAB : function () {
       //dump("Context: Edit AddressBook\n");
