@@ -29,12 +29,14 @@
 // its own GetFields function
 function GetFields()
 {
-  var emailaddr = document.getElementById("emailaddr").value;
+
+  var emailaddr = "dummy"
   var rv = { 
     emailaddr: { id: "emailaddr",      value: emailaddr       },
 
   }
   return rv; 
+  
 }
 
 // the setting procedure is unique to each page, and as such each page
@@ -51,24 +53,4 @@ function setNext(thelabel){
 	parent.wizardManager.wizardMap[parent.wizardManager.currentPageTag].next=thelabel
 } 
 
-function FAB_giveFocus(elementID){
-	dump("give FAB field Focus\n");
-	nameField = document.getElementById(elementID);
-	setTimeout("nameField.focus()",300);
-}
-
-function validate(data)
-{
-  var emailaddr = document.getElementById("emailaddr").value;
-  if (!emailaddr) {
-    aimErrorBox(aimString("msg.enterValidEmail"));
-    return false;
-  }
-  if (!validateEmailAddress(emailaddr)) {
-    aimErrorBox(aimString("msg.enterValidEmail"));
-    return false;
-  }
-  parent.wizardManager.LoadPage('findAFriend1_1_0',false);
-  return true;
-}
 
