@@ -1,25 +1,40 @@
-/* -*- Mode: Java; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
+/* -*- Mode: Java; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/* ***** BEGIN LICENSE BLOCK *****
+ * Version: NPL 1.1/GPL 2.0/LGPL 2.1
  *
- * The contents of this file are subject to the Netscape Public
- * License Version 1.1 (the "License"); you may not use this file
- * except in compliance with the License. You may obtain a copy of
- * the License at http://www.mozilla.org/NPL/
+ * The contents of this file are subject to the Netscape Public License
+ * Version 1.1 (the "License"); you may not use this file except in
+ * compliance with the License. You may obtain a copy of the License at
+ * http://www.mozilla.org/NPL/
  *
- * Software distributed under the License is distributed on an "AS
- * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
- * implied. See the License for the specific language governing
- * rights and limitations under the License.
+ * Software distributed under the License is distributed on an "AS IS" basis,
+ * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
+ * for the specific language governing rights and limitations under the
+ * License.
  *
  * The Original Code is mozilla.org code.
  *
- * The Initial Developer of the Original Code is Netscape
- * Communications Corporation.  Portions created by Netscape are
- * Copyright (C) 1998 Netscape Communications Corporation. All
- * Rights Reserved.
+ * The Initial Developer of the Original Code is 
+ * Netscape Communications Corporation.
+ * Portions created by the Initial Developer are Copyright (C) 1998
+ * the Initial Developer. All Rights Reserved.
  *
- * Contributor(s): 
+ * Contributor(s):
  *   Ben Goodger <ben@netscape.com> (Original Author)
- */
+ *
+ * Alternatively, the contents of this file may be used under the terms of
+ * either the GNU General Public License Version 2 or later (the "GPL"), or 
+ * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
+ * in which case the provisions of the GPL or the LGPL are applicable instead
+ * of those above. If you wish to allow use of your version of this file only
+ * under the terms of either the GPL or the LGPL, and not to allow others to
+ * use your version of this file under the terms of the NPL, indicate your
+ * decision by deleting the provisions above and replace them with the notice
+ * and other provisions required by the GPL or the LGPL. If you do not delete
+ * the provisions above, a recipient may use your version of this file under
+ * the terms of any one of the NPL, the GPL or the LGPL.
+ *
+ * ***** END LICENSE BLOCK ***** */
 
 var NC_NS  = "http://home.netscape.com/NC-rdf#";
 var RDF_NS = "http://www.w3.org/1999/02/22-rdf-syntax-ns#";
@@ -101,7 +116,6 @@ BookmarksUIElement.prototype = {
   createContextMenu: function (aEvent)
   {
     var popup = aEvent.target;
-    
     // clear out the old context menu contents (if any)
     while (popup.hasChildNodes()) 
       popup.removeChild(popup.firstChild);
@@ -111,11 +125,10 @@ BookmarksUIElement.prototype = {
     if (!("findRDFNode" in this))
       throw "Clients must implement findRDFNode!";
     var itemNode = this.findRDFNode(popupNode, true);
-    if (!itemNode || !itemNode.getAttribute("type") || itemNode.getAttribute("mode") == "edit") {
+    if (!itemNode || !itemNode.getAttributeNS(RDF_NS, "type") || itemNode.getAttribute("mode") == "edit") {
       aEvent.preventDefault();
       return;
     }
-
     if (!("getContextSelection" in this)) 
       throw "Clients must implement getContextSelection!";
     var selection = this.getContextSelection (itemNode);
@@ -143,7 +156,7 @@ BookmarksUIElement.prototype = {
       const kXULNS = "http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul";
       var currCommand = commonCommands[i].QueryInterface(Components.interfaces.nsIRDFResource).Value;
       var element = null;
-      if (currCommand != NC_NS_CMD + "separator") {
+      if (currCommand != NC_NS_CMD + "bm_separator") {
         var commandName = this.getCommandName(currCommand);
         element = this.createMenuItem(commandName, currCommand, itemNode);
       }
@@ -200,33 +213,56 @@ BookmarksUIElement.prototype = {
         return null;
     }
     var commands = [];
+    // menu order:
+    // 
+    // bm_open
+    // bm_openfolder
+    // bm_openinnewwindow
+    // /* bm_openinnewtab not yet supported */
+    // ---------------------
+    // /* bm_find removed */
+    // bm_newfolder
+    // ---------------------
+    // bm_cut
+    // bm_copy
+    // bm_paste
+    // bm_fileBookmark
+    // ---------------------
+    // bm_delete
+    // bm_rename
+    // ---------------------
+    // bm_properties
     switch (type) {
     case "http://home.netscape.com/NC-rdf#BookmarkSeparator":
-      commands = ["find", "separator", "bm_cut", "bm_copy", "bm_paste", 
-                  "bm_delete", "separator", "bm_fileBookmark", "separator", 
-                  "newfolder"];
+      commands = ["bm_newfolder", "bm_separator", 
+                  "bm_cut", "bm_copy", "bm_paste", "bm_separator",
+                  "bm_delete"];
       break;
     case "http://home.netscape.com/NC-rdf#Bookmark":
-      commands = ["open", "find", "separator", "bm_cut", 
-                  "bm_copy", "bm_paste", "bm_delete", "separator", "rename",
-                  "separator", "bm_fileBookmark", "separator", "newfolder", 
-                  "separator", "properties"];
+      commands = ["bm_open", "bm_openinnewwindow", /* "bm_openinnewtab", */ "bm_separator",
+                  "bm_newfolder", "bm_separator",
+                  "bm_cut", "bm_copy", "bm_paste", "bm_fileBookmark", "bm_separator",
+                  "bm_delete", "bm_rename", "bm_separator",
+                  "bm_properties"];
       break;
     case "http://home.netscape.com/NC-rdf#Folder":
-      commands = ["openfolder", "openfolderinnewwindow", "find", "separator", 
-                  "bm_cut", "bm_copy", "bm_paste", "bm_delete", "separator", "rename", 
-                  "separator", "bm_fileBookmark", "separator", 
-                  "newfolder", "separator", "properties"];
+      commands = ["bm_openfolder", "bm_openinnewwindow", "bm_separator", 
+                  "bm_newfolder", "bm_separator",
+                  "bm_cut", "bm_copy", "bm_paste", "bm_fileBookmark", "bm_separator",
+                  "bm_delete", "bm_rename", "bm_separator",
+                  "bm_properties"];
       break;
     case "http://home.netscape.com/NC-rdf#IEFavoriteFolder":
-      commands = ["open", "find", "separator", "bm_copy", "bm_delete", "separator", "rename", "separator",
-                  "bm_fileBookmark", "separator", "separator", "properties"];
+      commands = ["bm_openfolder", "bm_separator",
+                  "bm_delete"];
       break;
     case "http://home.netscape.com/NC-rdf#IEFavorite":
-      commands = ["open", "find", "separator", "bm_copy"];
+      commands = ["bm_open", "bm_openinnewwindow", /* "bm_openinnewtab", */ "bm_separator",
+                  "bm_copy"];
       break;
     case "http://home.netscape.com/NC-rdf#FileSystemObject":
-      commands = ["open", "find", "separator", "bm_copy"];
+      commands = ["bm_open", "bm_openinnewwindow", /* "bm_openinnewtab", */ "bm_separator",
+                  "bm_copy"];
       break;
     default: 
       var source = this.RDF.GetResource(aNodeID);
@@ -275,35 +311,38 @@ BookmarksUIElement.prototype = {
     if (selection.length >= 1) 
       var selectedItem = selection[0];
     switch (aCommandID) {
-    case "open":
-      this.open(null, selectedItem);
+    case "bm_open":
+      this.open(null, selectedItem, false);
       break;
-    case "openfolder":
+    case "bm_openfolder":
       this.commands.openFolder(selectedItem);
       break;
-    case "openfolderinnewwindow":
-      this.openFolderInNewWindow(selectedItem);
+    case "bm_openinnewwindow":
+      if (this.resolveType(selectedItem.id) == NC_NS + "Folder")
+        this.openFolderInNewWindow(selectedItem);
+      else
+        this.open(null, selectedItem, true);
       break;
-    case "rename":
+    case "bm_rename":
       // XXX - this is SO going to break if we ever do column re-ordering.
       this.commands.editCell(selectedItem, 0);
       break;
-    case "editurl":
+    case "bm_editurl":
       this.commands.editCell(selectedItem, 1);
       break;
-    case "setnewbookmarkfolder":
-    case "setpersonaltoolbarfolder":
-    case "setnewsearchfolder":
+    case "bm_setnewbookmarkfolder":
+    case "bm_setpersonaltoolbarfolder":
+    case "bm_setnewsearchfolder":
       BookmarksUtils.doBookmarksCommand(NODE_ID(selectedItem),
                                         NC_NS_CMD + aCommandID, args);
       // XXX - The containing node seems to be closed here and the 
       //       focus/selection is destroyed.
       this.selectElement(selectedItem);
       break;
-    case "properties":
+    case "bm_properties":
       this.showPropertiesForNode(selectedItem);
       break;
-    case "find":
+    case "bm_find":
       this.findInBookmarks();
       break;
     case "bm_cut":
@@ -341,16 +380,16 @@ BookmarksUIElement.prototype = {
         gBookmarksShell.flushDataSource();
       }
       break;
-    case "newfolder":
+    case "bm_newfolder":
       var nfseln = this.getBestItem();
       this.commands.createBookmarkItem("folder", nfseln);
       break;
-    case "newbookmark":
+    case "bm_newbookmark":
       var folder = this.getSelectedFolder();
       openDialog("chrome://communicator/content/bookmarks/addBookmark.xul", "", 
                  "centerscreen,chrome,modal=yes,dialog=yes,resizable=no", null, null, folder, null, "newBookmark");
       break;
-    case "newseparator":
+    case "bm_newseparator":
       nfseln = this.getBestItem();
       var parentNode = this.findRDFNode(nfseln, false);
       args = [{ property: NC_NS + "parent", 
@@ -358,9 +397,9 @@ BookmarksUIElement.prototype = {
       BookmarksUtils.doBookmarksCommand(NODE_ID(nfseln), 
                                         NC_NS_CMD + "newseparator", args);
       break;
-    case "import":
-    case "export":
-      const isImport = aCommandID == "import";
+    case "bm_import":
+    case "bm_export":
+      const isImport = aCommandID == "bm_import";
       try {
         const kFilePickerContractID = "@mozilla.org/filepicker;1";
         const kFilePickerIID = Components.interfaces.nsIFilePicker;
@@ -589,10 +628,10 @@ BookmarksUIElement.prototype = {
       // extra work to do - set the pref |browser.bookmarks.import_system_favorites|
       // to ensure that we don't re-import next time. 
       if (aSelection[count].getAttribute("type") == (NC_NS + "IEFavoriteFolder")) {
-        const kPrefSvcContractID = "@mozilla.org/preferences;1";
-        const kPrefSvcIID = Components.interfaces.nsIPref;
+        const kPrefSvcContractID = "@mozilla.org/preferences-service;1";
+        const kPrefSvcIID = Components.interfaces.nsIPrefBranch;
         const kPrefSvc = Components.classes[kPrefSvcContractID].getService(kPrefSvcIID);
-        kPrefSvc.SetBoolPref("browser.bookmarks.import_system_favorites", false);
+        kPrefSvc.setBoolPref("browser.bookmarks.import_system_favorites", false);
       }
         
       const krParent = this.RDF.GetResource(NODE_ID(currParent));
@@ -633,7 +672,7 @@ BookmarksUIElement.prototype = {
     kRDFC.RemoveElement(krSrc, true);
   },
   
-  open: function (aEvent, aRDFNode) 
+  open: function (aEvent, aRDFNode, aInNewWindow) 
   { 
     var urlValue = LITERAL(this.db, aRDFNode, NC_NS + "URL");
     
@@ -642,7 +681,7 @@ BookmarksUIElement.prototype = {
     
     if (aEvent && aEvent.altKey)   
       this.showPropertiesForNode (aRDFNode);
-    else if (this.openNewWindow)
+    else if (aInNewWindow)
       openDialog (getBrowserURL(), "_blank", "chrome,all,dialog=no", urlValue);
     else
       openTopWin (urlValue);
@@ -654,7 +693,7 @@ BookmarksUIElement.prototype = {
   {
     if (aBookmarkItem.getAttribute("type") != NC_NS + "BookmarkSeparator") 
       openDialog("chrome://communicator/content/bookmarks/bm-props.xul",
-                 "", "centerscreen,chrome,dialog=no,resizable=no", 
+                 "", "centerscreen,chrome,resizable=no", 
                  NODE_ID(aBookmarkItem));
   },
 
@@ -662,7 +701,7 @@ BookmarksUIElement.prototype = {
   {
     openDialog("chrome://communicator/content/bookmarks/findBookmark.xul",
                "FindBookmarksWindow",
-               "dialog=no,centerscreen,resizable=no,chrome,dependent");
+               "centerscreen,resizable=no,chrome,dependent");
   },
 
   getLocaleString: function (aStringKey)
@@ -763,8 +802,9 @@ var BookmarksUtils = {
       var rArc = this.RDF.GetResource(aArgumentsArray[i].property);
       argsArray.AppendElement(rArc);
       var rValue = null;
-      if ("resource" in aArgumentsArray[i]) 
+      if ("resource" in aArgumentsArray[i]) { 
         rValue = this.RDF.GetResource(aArgumentsArray[i].resource);
+      }
       else
         rValue = this.RDF.GetLiteral(aArgumentsArray[i].literal);
       argsArray.AppendElement(rValue);
@@ -777,51 +817,82 @@ var BookmarksUtils = {
 
   cloneFolder: function (aFolder, aParent, aRelativeItem) 
   {
-    const kBMDS = this.RDF.GetDataSource("rdf:bookmarks");
+    var BMDS = this.RDF.GetDataSource("rdf:bookmarks");
     
-    const krNameArc = this.RDF.GetResource(NC_NS + "Name");
-    var rName = kBMDS.GetTarget(aFolder, krNameArc, true);
+    var nameArc = this.RDF.GetResource(NC_NS + "Name");
+    var rName = BMDS.GetTarget(aFolder, nameArc, true);
     rName = rName.QueryInterface(Components.interfaces.nsIRDFLiteral);
     
-    const krNewFolder = this.createFolderWithID(rName.Value, aRelativeItem.Value, aParent.Value);
+	var newFolder = this.createFolderWithID(rName.Value, aRelativeItem, aParent);
     
     // Now need to append kiddies. 
     try {
       const kRDFCContractID = "@mozilla.org/rdf/container;1";
       const kRDFCIID = Components.interfaces.nsIRDFContainer;
-      const ksRDFC = Components.classes[kRDFCContractID].getService(kRDFCIID);
-      ksRDFC.Init(kBMDS, aFolder);
+      var RDFC = Components.classes[kRDFCContractID].getService(kRDFCIID);
+      RDFC.Init(BMDS, aFolder);
 
-      const kElts = ksRDFC.GetElements();
-      ksRDFC.Init(kBMDS, krNewFolder);
-      while (kElts.hasMoreElements()) {
-        var curr = kElts.getNext().QueryInterface(Components.interfaces.nsIRDFResource);
-        ksRDFC.AppendElement(curr);
+      var elts = RDFC.GetElements();
+      RDFC.Init(BMDS, newFolder);
+      while (elts.hasMoreElements()) {
+        var curr = elts.getNext().QueryInterface(Components.interfaces.nsIRDFResource);
+        RDFC.AppendElement(curr);
       }
     }
     catch (e) {
     }
-    return krNewFolder;
+    return newFolder;
   },
   
   createFolderWithID: function (aTitle, aRelativeItem, aParentFolder)
   {
-    const krBMDS = this.RDF.GetDataSource("rdf:bookmarks");
-    const kBMSvc = krBMDS.QueryInterface(Components.interfaces.nsIBookmarksService);
-    const krAnonymous = kBMSvc.GetAnonymousResource();
-    
-    var args = [{ property: NC_NS + "parent", resource: aParentFolder },
-                { property: NC_NS + "Name",   literal:  aTitle },
-                { property: NC_NS + "URL",    literal:  krAnonymous.Value}];
-    this.doBookmarksCommand(aRelativeItem, NC_NS_CMD + "newfolder", args);
+    const kRDFCContractID = "@mozilla.org/rdf/container;1";
+    const kRDFCIID = Components.interfaces.nsIRDFContainer;
+    var RDFC = Components.classes[kRDFCContractID].createInstance(kRDFCIID);
+    var BMDS = this.RDF.GetDataSource("rdf:bookmarks");
+    try {
+      RDFC.Init(BMDS, aParentFolder);
+    }
+    catch (e) {
+      return null;
+    }
+    var ix = RDFC.IndexOf(aRelativeItem);
 
-    // Tidy up.
-    const krURL = this.RDF.GetResource(NC_NS + "URL");
-    const krCurrURL = krBMDS.GetTarget(krAnonymous, krURL, true);
-    const krEmpty = this.RDF.GetLiteral("");
-    krBMDS.Change(krAnonymous, krURL, krCurrURL, krEmpty);
-    
-    return krAnonymous;
+    var BMSvc = BMDS.QueryInterface(Components.interfaces.nsIBookmarksService);
+    return BMSvc.createFolderWithDetails(aTitle, aParentFolder, ix);
+  },
+
+
+  addBookmarkForTabBrowser: function( aTabBrowser, aSelect )
+  {
+    var tabsInfo = [];
+    var currentTabInfo = { name: "", url: "", charset: null };
+
+    const activeBrowser = aTabBrowser.selectedBrowser;
+    const browsers = aTabBrowser.browsers;
+    for (var i = 0; i < browsers.length; ++i) {
+      var webNav = browsers[i].webNavigation;
+      var url = webNav.currentURI.spec;
+      var name = "";
+      var charset;
+      try {
+        var doc = webNav.document;
+        name = doc.title || url;
+        charset = doc.characterSet;
+      } catch (e) {
+        name = url;
+      }
+
+      tabsInfo[i] = { name: name, url: url, charset: charset };
+
+      if (browsers[i] == activeBrowser)
+        currentTabInfo = tabsInfo[i];
+    }
+
+    openDialog("chrome://communicator/content/bookmarks/addBookmark.xul", "",
+               "centerscreen,chrome,dialog=yes,resizable,dependent",
+               currentTabInfo.name, currentTabInfo.url, null,
+               currentTabInfo.charset, "addGroup" + (aSelect ? ",group" : ""), tabsInfo);
   },
 
   addBookmarkForBrowser: function (aDocShell, aShowDialog)
@@ -860,7 +931,7 @@ var BookmarksUtils = {
       const kBMSvcContractID = "@mozilla.org/browser/bookmarks-service;1";
       const kBMSvcIID = Components.interfaces.nsIBookmarksService;
       const kBMSvc = Components.classes[kBMSvcContractID].getService(kBMSvcIID);
-      kBMSvc.AddBookmark(aURL, aTitle, kBMSvcIID.BOOKMARK_DEFAULT_TYPE, aCharset);
+      kBMSvc.addBookmarkImmediately(aURL, aTitle, kBMSvcIID.BOOKMARK_DEFAULT_TYPE, aCharset);
     }
   }
 };
