@@ -140,14 +140,14 @@ function post_data_to_server(newLocation, data, pingMethod)
       if (!gSiteIdPerActivationSchema)
         gSiteIdPerActivationSchema = activationStrBundle.GetStringFromName("defaultSiteId");
 
-      chann.setRequestHeader("SNS-SITEID", gSiteIdPerActivationSchema, false);
+      chann.setRequestHeader("SNS-SITEID", gSiteIdPerActivationSchema);
 
       // get the charset
       var charset = activationStrBundle.GetStringFromName("charset");
 
       if (!data) {
         data = "siteId=" + escape(gSiteIdPerActivationSchema) + "&charset=" + escape(charset);
-        chann.setRequestHeader("HTTP-COOKIE", document.cookie, true);
+        chann.setRequestHeader("HTTP-COOKIE", document.cookie);
       }
       else {
         // Add charset to the data we are posting
@@ -1050,7 +1050,8 @@ function pingForTransactionUrls()
 function getActivationStartDialog()
 {
   var progressWindow;
-  var windowManagerInterface = Components.classes["@mozilla.org/appshell/window-mediator;1"].getService(Components.interfaces.nsIWindowMediator);
+  var windowManager = Components.classes['@mozilla.org/rdf/datasource;1?name=window-mediator'].getService();
+  var	windowManagerInterface = windowManager.QueryInterface( Components.interfaces.nsIWindowMediator);
   progressWindow = windowManagerInterface.getMostRecentWindow('activationStartWindow');
   return progressWindow;
 }
@@ -1058,7 +1059,8 @@ function getActivationStartDialog()
 function getProgressDialog(windowType)
 {
   var progressWindow;
-  var windowManagerInterface = Components.classes["@mozilla.org/appshell/window-mediator;1"].getService(Components.interfaces.nsIWindowMediator);
+  var windowManager = Components.classes['@mozilla.org/rdf/datasource;1?name=window-mediator'].getService();
+  var	windowManagerInterface = windowManager.QueryInterface( Components.interfaces.nsIWindowMediator);
   progressWindow = windowManagerInterface.getMostRecentWindow(windowType);
   return progressWindow;
 }
