@@ -55,28 +55,14 @@ var okCallback = null;
    (server vs. newsserver)
 */
 
-var gWizardMap = {
-    accounttype: { next: "identity" },
-    identity: { previous: "accounttype"}, // don't define next: server/newsserver
-    server:   { next: "login", previous: "identity"},
-    newsserver: { next: "accname", previous: "identity"},
-    login:    { next: "accname", previous: "server"}, 
-    accname:  { next: "done", }, // don't define previous: login/newsserver
-    done:     { previous: "accname", finish: true }
-}
-
-var pagePrefix="chrome://messenger/content/aw-";
-var pagePostfix=".xul";
-
-var currentPageTag;
-
 var contentWindow;
 
-var smtpService;
-var am;
-var accountm = Components.classes["@mozilla.org/messenger/account-manager;1"].getService(Components.interfaces.nsIMsgAccountManager);
-
-var accounts = accountm.accounts;
+var gPageData;
+var smtpService = Components.classes["@mozilla.org/messengercompose/smtp;1"].getService(Components.interfaces.nsISmtpService);
+var am = Components.classes["@mozilla.org/messenger/account-manager;1"].getService(Components.interfaces.nsIMsgAccountManager);
+var gPrefs = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
+var gMailSession = Components.classes["@mozilla.org/messenger/services/session;1"].getService(Components.interfaces.nsIMsgMailSession);
+var accounts = am.accounts;
 
 //accountCount indicates presence or absense of accounts
 var accountCount = accounts.Count();
@@ -101,59 +87,49 @@ var gCurrentAccountData;
 gDefaultSpecialFolderPickerMode = "0";
 
 // event handlers
-function onLoad() {
+function onAccountWizardLoad() {
     gPrefsBundle = document.getElementById("bundle_prefs");
     gMessengerBundle = document.getElementById("bundle_messenger");
 
-    // wizard stuff
-    // instantiate the Wizard Manager
-    wizardManager = new WizardManager( "wizardContents", null, null,
-                                       gWizardMap );
-    wizardManager.URL_PagePrefix = "chrome://messenger/content/aw-";
-    wizardManager.URL_PagePostfix = ".xul"; 
-    wizardManager.SetHandlers(null, null, onFinish, onCancel, null, null);
-	
-	/* We are checking here for the callback argument */
-	if (window.arguments && window.arguments[0])
-		if(window.arguments[0].okCallback ) 
-		{
-//			dump("There is okCallback");
-			top.okCallback = window.arguments[0].okCallback;
-		}
+    if ("testingIspServices" in this) {
+      if ("SetCustomizedWizardDimensions" in this && testingIspServices()) {
+        SetCustomizedWizardDimensions();
+      }
+    }
 
-    // load up the SMTP service for later
-    if (!smtpService) {
-        smtpService =
-            Components.classes["@mozilla.org/messengercompose/smtp;1"].getService(Components.interfaces.nsISmtpService);
+    /* We are checking here for the callback argument */
+    if (window.arguments && window.arguments[0]) {
+        if(window.arguments[0].okCallback ) 
+        {
+            //dump("There is okCallback");
+            top.okCallback = window.arguments[0].okCallback;
+        }
     }
 
     checkForInvalidAccounts();
-    var pageData = GetPageData();
-    updateMap(pageData, gWizardMap);
 
-    // skip the first page if we have an account
     if (gCurrentAccount) {
-        // skip past first pane
-        gWizardMap.identity.previous = null;
-        wizardManager.LoadPage("identity", false);
+        // Set the page index to identity page.
+        document.documentElement.pageIndex = 1;
     }
-    else
-        wizardManager.LoadPage("accounttype", false);
-    
+
     try {
-      gDefaultAccount = accountm.defaultAccount;
+        gDefaultAccount = am.defaultAccount;
     }
     catch (ex) {
-      // no default account, this is expected the first time you launch mail
-      // on a new profile
-      gDefaultAccount = null;
+        // no default account, this is expected the first time you launch mail
+        // on a new profile
+        gDefaultAccount = null;
     }
 }
 
     
 function onCancel() 
 {
+  if ("ActivationOnCancel" in this && ActivationOnCancel())
+    return false;
   var firstInvalidAccount = getFirstInvalidAccount();
+  var closeWizard = true;
 
   // if the user cancels the the wizard when it pops up because of 
   // an invalid account (example, a webmail account that activation started)
@@ -181,40 +157,29 @@ function onCancel()
     if (accountCount < 1) {
       var confirmMsg = gPrefsBundle.getString("cancelWizard");
       var confirmTitle = gPrefsBundle.getString("accountWizard");
-      var result = {value:0};
-
-      promptService.confirmEx(window, confirmTitle, confirmMsg,
+      var result = promptService.confirmEx(window, confirmTitle, confirmMsg,
         (promptService.BUTTON_TITLE_IS_STRING*promptService.BUTTON_POS_0)+
         (promptService.BUTTON_TITLE_IS_STRING*promptService.BUTTON_POS_1),
         gPrefsBundle.getString('WizardExit'),
         gPrefsBundle.getString('WizardContinue'), 
-        null, null, {value:0}, result);
+        null, null, {value:0});
 
-      if (result.value == 0)
-        window.close();
+      if (result == 1)
+        closeWizard = false;
     }
-    else
-      window.close();
 
-    if(top.okCallback) {
+    if(top.okCallback && closeWizard) {
       var state = false;
       top.okCallback(state);
     }
   }
+  return closeWizard;
 }
 
-function onFinish() {
-    if( !wizardManager.wizardMap[wizardManager.currentPageTag].finish )
-        return;
-
-	FinishAccount();
-}
-	
 function FinishAccount() {
+  try {
     var pageData = GetPageData();
 
-    dump(parent.wizardManager.WSM);
-
     var accountData= gCurrentAccountData;
     
     if (!accountData)
@@ -256,6 +221,9 @@ function FinishAccount() {
         top.okCallback(state);
     }
 }
+  catch(ex) { 
+  }
+}
 
 
 // prepopulate pageData with stuff from accountData
@@ -453,6 +421,22 @@ function finishAccount(account, accountData) {
         destIdentity.valid=true;
     }
 
+    /**
+     * If signature file need to be set, get the path to the signature file.
+     * Signature files, if exist, are placed under default location. Get
+     * default files location for messenger using directory service. Signature 
+     * file name should be extracted from the account data to build the complete
+     * path for signature file. Once the path is built, set the identity's signature pref.
+     */
+    if (destIdentity.attachSignature)
+    {
+        var sigFileName = accountData.signatureFileName;
+      
+        var sigFile = gMailSession.getDataFilesDir("messenger");
+        sigFile.append(sigFileName);
+        destIdentity.signature = sigFile;
+    }
+
     // don't try to create an smtp server if we already have one.
     if (!destIdentity.smtpServerKey)
     {
@@ -471,14 +455,26 @@ function finishAccount(account, accountData) {
 
         dump("Copying smtpServer (" + smtpServer + ") to accountData\n");
         //set the smtp server to be the default only if it is not a redirectorType
-        if (accountData.smtp.redirectorType == null)
-          smtpService.defaultServer = smtpServer;
+        if (accountData.smtp.redirectorType == null) 
+        {
+          if ((smtpService.defaultServer.hostname == null) || (smtpService.defaultServer.redirectorType != null))
+            smtpService.defaultServer = smtpServer;
+        }
 
         copyObjectToInterface(smtpServer, accountData.smtp);
 
-        // some identities have 'preferred' 
-        if (accountData.smtpUsePreferredServer && destIdentity)
+        // refer bug#141314
+        // since we clone the default smtpserver with the new account's username
+        // force every account to use the smtp server that was created or assigned to it in the
+        // case of isps using rdf files
+
+        try{
             destIdentity.smtpServerKey = smtpServer.key;
+        }
+        catch(ex)
+        {
+          dump("There is no smtp server assigned to this account: Exception= "+ex+"\n");
+        }
      }
 
      if (this.FinishAccountHook != undefined) {
@@ -569,7 +565,7 @@ function setDefaultCopiesAndFoldersPrefs(identity, server)
 {
 	dump("finding folders on server = " + server.hostName + "\n");
 
-	var rootFolder = server.RootFolder;
+	var rootFolder = server.rootFolder;
 
 	// we need to do this or it is possible that the server's draft,
     // stationery fcc folder will not be in rdf
@@ -606,13 +602,12 @@ function setDefaultCopiesAndFoldersPrefs(identity, server)
     if (protocolInfo.needToBuildSpecialFolderURIs)
     {
         var folderDelim = "/";
-        var sentFolderName =  gMessengerBundle.getString("sentFolderName");
-        var draftsFolderName =  gMessengerBundle.getString("draftsFolderName");
-        var templatesFolderName =  gMessengerBundle.getString("templatesFolderName");
 
-        identity.draftFolder = msgFolder.server.serverURI+ folderDelim + draftsFolderName;
-        identity.stationeryFolder = msgFolder.server.serverURI+ folderDelim + templatesFolderName;
-        identity.fccFolder = msgFolder.server.serverURI+ folderDelim + sentFolderName;
+        /* we use internal names known to everyone like Sent, Templates and Drafts */
+
+        identity.draftFolder = msgFolder.server.serverURI+ folderDelim + "Drafts";
+        identity.stationeryFolder = msgFolder.server.serverURI+ folderDelim + "Templates";
+        identity.fccFolder = msgFolder.server.serverURI+ folderDelim + "Sent";
     }
     else {
         // these hex values come from nsMsgFolderFlags.h
@@ -639,7 +634,7 @@ function AccountExists(userName,hostName,serverType)
   var accountExists = false;
   var accountManager = Components.classes["@mozilla.org/messenger/account-manager;1"].getService(Components.interfaces.nsIMsgAccountManager);
   try {
-        var server = accountManager.FindServer(userName,hostName,serverType);
+        var server = accountManager.findRealServer(userName,hostName,serverType);
         if (server) {
                 accountExists = true;
         }
@@ -679,21 +674,66 @@ function checkForInvalidAccounts()
         var identity =
             firstInvalidAccount.identities.QueryElementAt(0, nsIMsgIdentity);
 
+        var accountData = null;
+        // If there is a email address already provided, try to get to other ISP defaults.
+        // If not, get pre-configured data, if any.
+        if (identity.email) {
         dump("Invalid account: trying to get ISP data for " + identity.email + "\n");
-        var accountData = getIspDefaultsForEmail(identity.email);
+        accountData = getIspDefaultsForEmail(identity.email);
         dump("Invalid account: Got " + accountData + "\n");
         
         // account -> accountData -> pageData
         accountData = AccountToAccountData(firstInvalidAccount, accountData);
+        }
+        else {
+          accountData = getPreConfigDataForAccount(firstInvalidAccount);
+        }
         
         AccountDataToPageData(accountData, pageData);
 
         gCurrentAccountData = accountData;
-        
-        dump(parent.wizardManager.WSM);
     }
 }
 
+// Transfer all invalid account information to AccountData. Also, get those special 
+// preferences (not associated with any interfaces but preconfigurable via prefs or rdf files) 
+// like whether not the smtp server associated with this account requires 
+// a user name (mail.identity.<id_key>.smtpRequiresUsername) and the choice of skipping 
+// panels (mail.identity.<id_key>.wizardSkipPanels).
+function getPreConfigDataForAccount(account)
+{
+  var accountData = new Object;
+  accountData = new Object;
+  accountData.incomingServer = new Object;
+  accountData.identity = new Object;
+  accountData.smtp = new Object;
+
+  accountData = AccountToAccountData(account, null);
+        
+  var identity = account.identities.QueryElementAt(0, nsIMsgIdentity);
+
+  try {
+    var skipPanelsPrefStr = "mail.identity." + identity.key + ".wizardSkipPanels";
+    accountData.wizardSkipPanels = gPrefs.getBoolPref(skipPanelsPrefStr);
+
+    if (identity.smtpServerKey) {
+      var smtpServer = smtpService.getServerByKey(identity.smtpServerKey);
+      accountData.smtp = smtpServer;
+
+      var smtpRequiresUsername = false;
+      var smtpRequiresPrefStr = "mail.identity." + identity.key + ".smtpRequiresUsername";
+      smtpRequiresUsername = gPrefs.getBoolPref(smtpRequiresPrefStr);
+      accountData.smtpRequiresUsername = smtpRequiresUsername;
+    }
+  }
+  catch(ex) {
+    // reached here as special identity pre-configuration prefs 
+    // (wizardSkipPanels, smtpRequiresUsername) are not defined.
+  }
+
+  return accountData;
+}
+
 function AccountToAccountData(account, defaultAccountData)
 {
     dump("AccountToAccountData(" + account + ", " +
@@ -704,7 +744,8 @@ function AccountToAccountData(account, defaultAccountData)
     
     accountData.incomingServer = account.incomingServer;
     accountData.identity = account.identities.QueryElementAt(0, nsIMsgIdentity);
-    accountData.smtp = smtpService.defaultServer;
+    try {accountData.smtp = smtpService.defaultServer;}
+    catch (ex){}
 
     return accountData;
 }
@@ -727,9 +768,9 @@ function setPageData(pageData, tag, slot, value) {
 
 // value of checkbox on the first page
 function serverIsNntp(pageData) {
-    if (pageData.accounttype.newsaccount)
-        return pageData.accounttype.newsaccount.value;
-    return false;
+  if (pageData.accounttype.newsaccount)
+    return pageData.accounttype.newsaccount.value;
+  return false;
 }
 
 function getUsernameFromEmail(email)
@@ -770,48 +811,12 @@ function getCurrentHostname(pageData) {
         return pageData.server.hostname.value;
 }
 
-function UpdateWizardMap() {
-    updateMap(GetPageData(), gWizardMap);
-}
-
-// updates the map based on various odd states
-// conditions handled right now:
-// - 
-function updateMap(pageData, wizardMap) {
-    dump("Updating wizard map..\n");
-    if (pageData.accounttype) {
-        var ismailaccount = pageData.accounttype.mailaccount;
-        dump("Accounttype is mail: " + (ismailaccount && ismailaccount.value) + "\n");
-        // set up default account stuff
-        wizardMap.identity.next = "server";
-        wizardMap.done.previous = "accname";
-        
-        if (pageData.accounttype.mailaccount &&
-            pageData.accounttype.mailaccount.value) {
-
-            wizardMap.accname.previous = "login";
-            
-            if (gCurrentAccountData && gCurrentAccountData.wizardSkipPanels) {
-                wizardMap.identity.next = "done";
-                wizardMap.done.previous = "identity";
-            }
-        }
-
-        else if (pageData.accounttype.newsaccount &&
-                 pageData.accounttype.newsaccount.value) {
-            wizardMap.identity.next = "newsserver";
-            wizardMap.accname.previous = "newsserver";
-        }
-        else {
-            dump("Handle other types (" + pageData.accounttype + ") here?\n");
-        }
-    }
-
-}
-
 function GetPageData()
 {
-    return parent.wizardManager.WSM.PageData;
+    if (!gPageData)
+      gPageData = new Object;
+
+    return gPageData;
 }
     
 
@@ -823,6 +828,10 @@ function PrefillAccountForIsp(ispName)
     
     var pageData = GetPageData();
 
+    if (!ispData) {
+      SetCurrentAccountData(null);
+      return;
+    }
 
     // prefill the rest of the wizard
     dump("PrefillAccountForISP: filling with " + ispData + "\n");
@@ -876,9 +885,8 @@ function getInterfaceForType(type) {
 
 // flush the XUL cache - just for debugging purposes - not called
 function onFlush() {
-        var prefs = Components.classes["@mozilla.org/preferences;1"].getService(Components.interfaces.nsIPref);
-        prefs.SetBoolPref("nglayout.debug.disable_xul_cache", true);
-        prefs.SetBoolPref("nglayout.debug.disable_xul_cache", false);
+        gPrefs.setBoolPref("nglayout.debug.disable_xul_cache", true);
+        gPrefs.setBoolPref("nglayout.debug.disable_xul_cache", false);
 
 }
 
@@ -892,7 +900,7 @@ function EnableCheckMailAtStartUpIfNeeded(newAccount)
     // a default account. If no such account, make this one as the default account 
     // and turn on the new mail check at startup for the current account   
     if (!(gDefaultAccount && gDefaultAccount.incomingServer.canBeDefaultServer)) { 
-        accountm.defaultAccount = newAccount;
+        am.defaultAccount = newAccount;
         newAccount.incomingServer.loginAtStartUp = true;
     }
 }
@@ -906,3 +914,9 @@ function SetSmtpRequiresUsernameAttribute(accountData)
         accountData.smtpRequiresUsername = true;
     }
 }
+
+function setNextPage(currentPageId, nextPageId) {
+    var currentPage = document.getElementById(currentPageId);
+    currentPage.next = nextPageId;
+}
+
