@@ -41,6 +41,20 @@ var gPrefsBundle;
 var gOnMailServersPage;
 var gOnNewsServerPage;
 
+function hostnameIsIllegal(hostname)
+{
+  // XXX TODO do a complete check.
+  // this only checks for illegal characters in the hostname
+  // but hostnames like "...." and "_" and ".111" will get by
+  // my test.  
+  var validChars = hostname.match(/[A-Za-z0-9.-]/g);
+  if (!validChars || (validChars.length != hostname.length)) {
+    return true;
+  }
+
+  return false;
+}
+
 function serverPageValidate() 
 {
   var smtpserver = document.getElementById("smtphostname");
@@ -97,17 +111,13 @@ function serverPageInit() {
   if (gOnNewsServerPage)
   {
     var newsServer = document.getElementById("newsServer");
-    var pageData = parent.GetPageData();
-    try 
-    {
-      newsServer.value = pageData.newsserver.hostname.value;
-    }
-    catch (ex){}
+    var pageData = parent.GetPageData()
+    newsServer.value = pageData.newsserver.hostname.value;
   }
     
+
   // Server type selection (pop3 or imap) is for mail accounts only
-  var pageData = parent.GetPageData();
-  var isMailAccount = pageData.accounttype.mailaccount;
+  var isMailAccount = parent.GetPageData().accounttype.mailaccount;
   if (isMailAccount && isMailAccount.value){
     var serverTypeRadioGroup = document.getElementById("servertype");
     /* 
@@ -129,11 +139,7 @@ function serverPageInit() {
   gPrefsBundle = document.getElementById("bundle_prefs");
   var smtpServer = null;
   try {
-    // don't use the default smtp server if it has a redirector type
-    if (!parent.smtpService.defaultServer.redirectorType) {
-      smtpServer = parent.smtpService.defaultServer;
-      setPageData(pageData, "identity", "smtpServerKey", smtpServer.key);
-    }
+    smtpServer = parent.smtpService.defaultServer;
   }
   catch(ex){}
 
