@@ -55,20 +55,17 @@ function GetMsgFolderFromResource(folderResource)
      return null;
 
   var msgFolder = folderResource.QueryInterface(Components.interfaces.nsIMsgFolder);
-  return msgFolder;
-}
-
-function GetMsgFolderFromURI(folderURI)
-{
-  var folderResource = RDF.GetResource(folderURI);
-  return GetMsgFolderFromResource(folderResource);
+  if (msgFolder && (msgFolder.parent || msgFolder.isServer))
+    return msgFolder;
+  else
+    return null;
 }
 
 function GetServer(uri)
 {
     if (!uri) return null;
     try {
-        var folder = GetMsgFolderFromUri(uri);
+        var folder = GetMsgFolderFromUri(uri, true);
         return folder.server;
     }
     catch (ex) {
@@ -147,11 +144,26 @@ function setTitleFromFolder(msgfolder, subject)
     window.title = title;
 }
 
+function UpdateMailToolbar(caller)
+{
+  //dump("XXX update mail-toolbar " + caller + "\n");
+  document.commandDispatcher.updateCommands('mail-toolbar');
+
+  // hook for extra toolbar items
+  var observerService = Components.classes["@mozilla.org/observer-service;1"].getService(Components.interfaces.nsIObserverService);
+  observerService.notifyObservers(window, "mail:updateToolbarItems", null);
+}
+
 function ChangeFolderByURI(uri, viewType, viewFlags, sortType, sortOrder)
 {
   //dump("In ChangeFolderByURI uri = " + uri + " sortType = " + sortType + "\n");
   if (uri == gCurrentLoadingFolderURI)
     return;
+
+  // hook for extra toolbar items
+  var observerService = Components.classes["@mozilla.org/observer-service;1"].getService(Components.interfaces.nsIObserverService);
+  observerService.notifyObservers(window, "mail:setupToolbarItems", uri);
+
   var resource = RDF.GetResource(uri);
   var msgfolder =
       resource.QueryInterface(Components.interfaces.nsIMsgFolder);
@@ -189,48 +201,45 @@ function ChangeFolderByURI(uri, viewType, viewFlags, sortType, sortOrder)
       HideAccountCentral();
   }
 
-  if (showPerformance) {
-    gBeforeFolderLoadTime = new Date();
+  if (gFakeAccountPageLoaded)
+  {
+      HideFakeAccountPage();
   }
 
   gCurrentLoadingFolderURI = uri;
   gNextMessageAfterDelete = null; // forget what message to select, if any
 
-  if(msgfolder.manyHeadersToDownload())
+  gCurrentFolderToReroot = uri;
+  gCurrentLoadingFolderViewFlags = viewFlags;
+  gCurrentLoadingFolderViewType = viewType;
+  gCurrentLoadingFolderSortType = sortType;
+  gCurrentLoadingFolderSortOrder = sortOrder;
+  if(msgfolder.manyHeadersToDownload || msgfolder.server.redirectorType == "aol")
   {
-  try
-  {
-    SetBusyCursor(window, true);
-    gCurrentFolderToReroot = uri;
-    gCurrentLoadingFolderViewFlags = viewFlags;
-    gCurrentLoadingFolderViewType = viewType;
-    gCurrentLoadingFolderSortType = sortType;
-    gCurrentLoadingFolderSortOrder = sortOrder;
-    msgfolder.startFolderLoading();
-    msgfolder.updateFolder(msgWindow);
-  }
-  catch(ex)
-  {
-        SetBusyCursor(window, false);
-        dump("Error loading with many headers to download: " + ex + "\n");
-  }
+    gRerootOnFolderLoad = true;
+    try
+    {
+      SetBusyCursor(window, true);
+      msgfolder.startFolderLoading();
+      msgfolder.updateFolder(msgWindow);
+    }
+    catch(ex)
+    {
+          SetBusyCursor(window, false);
+          dump("Error loading with many headers to download: " + ex + "\n");
+    }
   }
   else
   {
     SetBusyCursor(window, true);
-    gCurrentFolderToReroot = "";
-    gCurrentLoadingFolderViewFlags = 0;  // is this correct?
-    gCurrentLoadingFolderSortType = 0;  // is this correct?
-    gCurrentLoadingFolderSortOrder = 0;  // is this correct?
-    gCurrentLoadingFolderViewType = 0;  // is this correct?
     RerootFolder(uri, msgfolder, viewType, viewFlags, sortType, sortOrder);
+    gRerootOnFolderLoad = false;
+    msgfolder.startFolderLoading();
 
     //Need to do this after rerooting folder.  Otherwise possibility of receiving folder loaded
     //notification before folder has actually changed.
     msgfolder.updateFolder(msgWindow);
   }
-
-  document.commandDispatcher.updateCommands('mail-toolbar');
 }
 
 function isNewsURI(uri)
@@ -239,7 +248,7 @@ function isNewsURI(uri)
         return false;
     }
     else {
-        return ((uri.substring(0,6) == "news:/") || (uri.substring(0,14) == "news_message:/"));
+        return ((uri.substring(0,6) == "news:/") || (uri.substring(0,14) == "news-message:/"));
     }
 }
 
@@ -289,16 +298,32 @@ function RerootFolder(uri, newFolder, viewType, viewFlags, sortType, sortOrder)
 
   // now create the db view, which will sort it.
   CreateDBView(newFolder, viewType, viewFlags, sortType, sortOrder);
-  // that should have initialized gDBView, now re-root the thread pane
-  var outlinerView = gDBView.QueryInterface(Components.interfaces.nsIOutlinerView);
-  if (outlinerView)
+  if (oldFolder)
   {
-    var outliner = GetThreadOutliner();
-    outliner.boxObject.QueryInterface(Components.interfaces.nsIOutlinerBoxObject).view = outlinerView;
+    /*disable quick search clear button if we were in the search view on folder switching*/
+    disableQuickSearchClearButton();
+
+     /*we don't null out the db reference for inbox because inbox is like the "main" folder
+       and performance outweighs footprint */
+    if (!IsSpecialFolder(oldFolder, MSG_FOLDER_FLAG_INBOX))
+      if (oldFolder.URI != newFolder.URI)
+        oldFolder.setMsgDatabase(null);
+  }
+  // that should have initialized gDBView, now re-root the thread pane
+  var treeView = gDBView.QueryInterface(Components.interfaces.nsITreeView);
+  if (treeView)
+  {
+    var tree = GetThreadTree();
+    tree.boxObject.QueryInterface(Components.interfaces.nsITreeBoxObject).view = treeView;
   }
 
   SetUpToolbarButtons(uri);
+
   UpdateStatusMessageCounts(newFolder);
+  
+  // hook for extra toolbar items
+  var observerService = Components.classes["@mozilla.org/observer-service;1"].getService(Components.interfaces.nsIObserverService);
+  observerService.notifyObservers(window, "mail:updateToolbarItems", null);
 }
 
 function SwitchView(command)
@@ -346,25 +371,27 @@ function SwitchView(command)
   }
 
   // that should have initialized gDBView, now re-root the thread pane
-  var outlinerView = gDBView.QueryInterface(Components.interfaces.nsIOutlinerView);
-  if (outlinerView)
+  var treeView = gDBView.QueryInterface(Components.interfaces.nsITreeView);
+  if (treeView)
   {
-    var outliner = GetThreadOutliner();
-    outliner.boxObject.QueryInterface(Components.interfaces.nsIOutlinerBoxObject).view = outlinerView;
+    var tree = GetThreadTree();
+    tree.boxObject.QueryInterface(Components.interfaces.nsITreeBoxObject).view = treeView;
   }
 }
 
 function SetSentFolderColumns(isSentFolder)
 {
   var senderOrRecipientColumn = document.getElementById("senderOrRecipientCol");
-
+  var searchCriteria = document.getElementById("searchCriteria");
   if(isSentFolder)
   {
     senderOrRecipientColumn.setAttribute("label", gMessengerBundle.getString("recipientColumnHeader"));
+    searchCriteria.setAttribute("value", gMessengerBundle.getString("recipientSearchCriteria"));
   }
   else
   {
     senderOrRecipientColumn.setAttribute("label", gMessengerBundle.getString("senderColumnHeader"));
+    searchCriteria.setAttribute("value", gMessengerBundle.getString("senderSearchCriteria"));
   }
 }
 
@@ -440,6 +467,9 @@ function ConvertColumnIDToSortType(columnID)
     case "threadCol":
       sortKey = nsMsgViewSortType.byThread;
       break;
+    case "labelCol":
+      sortKey = nsMsgViewSortType.byLabel;
+      break;
     default:
       dump("unsupported sort column: " + columnID + "\n");
       sortKey = 0;
@@ -476,6 +506,9 @@ function ConvertSortTypeToColumnID(sortKey)
     case nsMsgViewSortType.byStatus:
       columnID = "statusCol";
       break;
+    case nsMsgViewSortType.byLabel:
+      columnID = "labelCol";
+      break;
     case nsMsgViewSortType.bySize:
       columnID = "sizeCol";
       break;
@@ -512,7 +545,7 @@ var gCurViewFlags;
 var gCurSortType;
 
 // CreateDBView is called when we have a thread pane. CreateBareDBView is called when there is no
-// outliner associated with the view. CreateDBView will call into CreateBareDBView...
+// tree associated with the view. CreateDBView will call into CreateBareDBView...
 
 function CreateBareDBView(msgFolder, viewType, viewFlags, sortType, sortOrder)
 {
@@ -558,11 +591,11 @@ function CreateDBView(msgFolder, viewType, viewFlags, sortType, sortOrder)
   // call the inner create method
   CreateBareDBView(msgFolder, viewType, viewFlags, sortType, sortOrder);
 
-  // now do outliner specific work
+  // now do tree specific work
 
   // based on the collapsed state of the thread pane/message pane splitter,
-  // supress message display if appropriate.
-  gDBView.supressMsgDisplay = IsThreadAndMessagePaneSplitterCollapsed();
+  // suppress message display if appropriate.
+  gDBView.suppressMsgDisplay = IsThreadAndMessagePaneSplitterCollapsed();
 
   UpdateSortIndicators(gCurSortType, sortOrder);
 }
@@ -590,33 +623,13 @@ function UpdateSortIndicator(column,sortDirection)
   // this is obsolete
 }
 
-function SortFolderPane(column)
-{
-  var node = FindInSidebar(window, column);
-  if(!node)
-  {
-    dump('Couldnt find sort column\n');
-    return false;
-  }
-
-  try 
-  {
-    var folderOutliner = GetFolderOutliner();
-    folderOutliner.outlinerBoxObject.view.cycleHeader(column, node);
-  }
-  catch (ex) 
-  {
-    dump("failed to cycle header: " + ex + "\n");
-  }
-}
-
 function GetSelectedFolderResource()
 {
-    var folderOutliner = GetFolderOutliner();
+    var folderTree = GetFolderTree();
     var startIndex = {};
     var endIndex = {};
-    folderOutliner.outlinerBoxObject.selection.getRangeAt(0, startIndex, endIndex);
-    return GetFolderResource(folderOutliner, startIndex.value);
+    folderTree.treeBoxObject.selection.getRangeAt(0, startIndex, endIndex);
+    return GetFolderResource(folderTree, startIndex.value);
 }
 
 function OnMouseUpThreadAndMessagePaneSplitter()
@@ -624,7 +637,7 @@ function OnMouseUpThreadAndMessagePaneSplitter()
   if (gDBView) {
     // the collapsed state is the state after we released the mouse 
     // so we take it as it is
-    gDBView.supressMsgDisplay = IsThreadAndMessagePaneSplitterCollapsed();
+    gDBView.suppressMsgDisplay = IsThreadAndMessagePaneSplitterCollapsed();
   }
   }
 
@@ -633,19 +646,35 @@ function OnClickThreadAndMessagePaneSplitterGrippy()
   if (gDBView) {
     // the collapsed state is the state when we clicked on the grippy
     // not when afterwards, so we need to reverse this value
-    gDBView.supressMsgDisplay = !IsThreadAndMessagePaneSplitterCollapsed();
+    gDBView.suppressMsgDisplay = !IsThreadAndMessagePaneSplitterCollapsed();
    }
 }
 
 function FolderPaneSelectionChange()
 {
-    var folderOutliner = GetFolderOutliner();
-    if (folderOutliner.outlinerBoxObject.selection.count == 1)
+    var folderTree = GetFolderTree();
+    var folderSelection = folderTree.treeBoxObject.selection;
+
+    // This prevents a folder from being loaded in the case that the user
+    // has right-clicked on a folder different from the one that was
+    // originally highlighted.  On a right-click, the highlight (selection)
+    // of a row will be different from the value of currentIndex, thus if
+    // the currentIndex is not selected, it means the user right-clicked
+    // and we don't want to load the contents of the folder.
+    if (!folderSelection.isSelected(folderSelection.currentIndex))
+      return;
+
+    if(gTimelineEnabled) {
+      gTimelineService.startTimer("FolderLoading");
+      gTimelineService.enter("FolderLoading has Started");
+    }
+
+    if (folderSelection.count == 1)
     {
         var startIndex = {};
         var endIndex = {};
-        folderOutliner.outlinerBoxObject.selection.getRangeAt(0, startIndex, endIndex);
-        var folderResource = GetFolderResource(folderOutliner, startIndex.value);
+        folderSelection.getRangeAt(0, startIndex, endIndex);
+        var folderResource = GetFolderResource(folderTree, startIndex.value);
         var msgFolder = folderResource.QueryInterface(Components.interfaces.nsIMsgFolder);
         if (msgFolder == msgWindow.openFolder)
             return;
@@ -670,6 +699,8 @@ function FolderPaneSelectionChange()
                   sortOrder = dbFolderInfo.sortOrder;
                   viewFlags = dbFolderInfo.viewFlags;
                   viewType = dbFolderInfo.viewType;
+                  msgDatabase = null;
+                  dbFolderInfo = null;
                 }
               }
               catch (ex)
@@ -677,6 +708,13 @@ function FolderPaneSelectionChange()
                 dump("failed to get view & sort values.  ex = " + ex +"\n");
               }
             }
+            if (gDBView && gDBView.isSearchView)
+            {
+              gDBView.isSearchView = false;  //reset the search input on folder switch
+              var searchInput = document.getElementById("searchInput");
+              if (searchInput) 
+                searchInput.value = "";
+            }
             ChangeFolderByURI(folderResource.Value, viewType, viewFlags, sortType, sortOrder);
         }
     }
@@ -686,14 +724,21 @@ function FolderPaneSelectionChange()
         ClearThreadPane();
     }
 
-    if (! gAccountCentralLoaded)
-        ClearMessagePane();
+    if (gAccountCentralLoaded)
+      UpdateMailToolbar("gAccountCentralLoaded");
+    else if (gFakeAccountPageLoaded)
+      UpdateMailToolbar("gFakeAccountPageLoaded");
+    else {
+      document.getElementById('advancedButton').setAttribute("disabled" , !(IsCanSearchMessagesEnabled()));
+      ClearMessagePane();
+    }
 
     if (gDisplayStartupPage)
     {
         loadStartPage();
         gDisplayStartupPage = false;
-    }
+        UpdateMailToolbar("gDisplayStartupPage");
+    }    
 }
 
 function ClearThreadPane()
@@ -710,20 +755,13 @@ function IsSpecialFolder(msgFolder, flags)
         return false;
     }
     else if ((msgFolder.flags & flags) == 0) {
-        var folder = msgFolder.QueryInterface(Components.interfaces.nsIFolder);
+	  var parentMsgFolder = msgFolder.parentMsgFolder;
 
-        if (folder && folder.parent) {
-            var parentMsgFolder = folder.parent.QueryInterface(Components.interfaces.nsIMsgFolder);
+      if(!parentMsgFolder) {
+         return false;
+      }
 
-            if(!parentMsgFolder) {
-                return false;
-            }
-
-            return IsSpecialFolder(parentMsgFolder, flags);
-        }
-        else {
-            return false;
-        }
+      return IsSpecialFolder(parentMsgFolder, flags);
     }
     else {
         // the user can set their INBOX to be their SENT folder.
@@ -774,7 +812,7 @@ function Redo()
     messenger.Redo(msgWindow);
 }
 var mailOfflineObserver = {
-  Observe: function(subject, topic, state) {
+  observe: function(subject, topic, state) {
     // sanity checks
     if (topic != "network:offline-status-changed") return;
     MailOfflineStateChanged(state == "offline");
@@ -784,12 +822,12 @@ var mailOfflineObserver = {
 function AddMailOfflineObserver() 
 {
   var observerService = Components.classes["@mozilla.org/observer-service;1"].getService(Components.interfaces.nsIObserverService); 
-  observerService.AddObserver(mailOfflineObserver, "network:offline-status-changed");
+  observerService.addObserver(mailOfflineObserver, "network:offline-status-changed", false);
 }
 
 function RemoveMailOfflineObserver()
 {
   var observerService = Components.classes["@mozilla.org/observer-service;1"].getService(Components.interfaces.nsIObserverService); 
-  observerService.RemoveObserver(mailOfflineObserver,"network:offline-status-changed");
+  observerService.removeObserver(mailOfflineObserver,"network:offline-status-changed");
 }
 
