@@ -47,10 +47,17 @@ var FolderPaneController =
 
 	isCommandEnabled: function(command)
 	{
-        //		dump("FolderPaneController.IsCommandEnabled(" + command + ")\n");
+    //dump("FolderPaneController isCommandEnabled called\n");
+    if (IsFakeAccount()) 
+      return false;
+
 		switch ( command )
 		{
 			case "cmd_selectAll":
+                                // the folder pane (currently)
+                                // only handles single selection
+                                // so we forward select all to the thread pane
+				return true;  
 			case "cmd_cut":
 			case "cmd_copy":
 			case "cmd_paste":
@@ -59,20 +66,20 @@ var FolderPaneController =
 			case "button_delete":
 				if ( command == "cmd_delete" )
 					goSetMenuValue(command, 'valueFolder');
-                                var folderOutliner = GetFolderOutliner();
+                                var folderTree = GetFolderTree();
                                 var startIndex = {};
                                 var endIndex = {};
-                                folderOutliner.outlinerBoxObject.selection.getRangeAt(0, startIndex, endIndex);
+                                folderTree.treeBoxObject.selection.getRangeAt(0, startIndex, endIndex);
                                 if (startIndex.value >= 0) {
                                         var canDeleteThisFolder;
 					var specialFolder = null;
 					var isServer = null;
 					var serverType = null;
 					try {
-                                                var folderResource = GetFolderResource(folderOutliner, startIndex.value);
-                                                specialFolder = GetFolderAttribute(folderOutliner, folderResource, "SpecialFolder");
-                                                isServer = GetFolderAttribute(folderOutliner, folderResource, "IsServer");
-                                                serverType = GetFolderAttribute(folderOutliner, folderResource, "ServerType");
+                                                var folderResource = GetFolderResource(folderTree, startIndex.value);
+                                                specialFolder = GetFolderAttribute(folderTree, folderResource, "SpecialFolder");
+                                                isServer = GetFolderAttribute(folderTree, folderResource, "IsServer");
+                                                serverType = GetFolderAttribute(folderTree, folderResource, "ServerType");
                                                 if (serverType == "nntp") {
 			     	                        if ( command == "cmd_delete" ) {
 					                        goSetMenuValue(command, 'valueNewsgroup');
@@ -83,7 +90,7 @@ var FolderPaneController =
 					catch (ex) {
 						//dump("specialFolder failure: " + ex + "\n");
 					}
-                                        if (specialFolder == "Inbox" || specialFolder == "Trash" || isServer == "true")
+                                        if (specialFolder == "Inbox" || specialFolder == "Trash" || specialFolder == "Drafts" || specialFolder == "Sent" || specialFolder == "Templates" || specialFolder == "Unsent Messages" || isServer == "true")
                                                 canDeleteThisFolder = false;
                                         else
                                                 canDeleteThisFolder = true;
@@ -109,6 +116,12 @@ var FolderPaneController =
 			case "button_delete":
 				MsgDeleteFolder();
 				break;
+			case "cmd_selectAll":
+                                // the folder pane (currently)
+                                // only handles single selection
+                                // so we forward select all to the thread pane
+                                SendCommandToThreadPane(command);
+                                break;
 		}
 	},
 	
@@ -143,6 +156,7 @@ var ThreadPaneController =
 
 	isCommandEnabled: function(command)
 	{
+    //dump("ThreadPaneController isCommandEnabled called\n");
 		switch ( command )
 		{
 			case "cmd_selectAll":
@@ -171,6 +185,7 @@ var ThreadPaneController =
                 // if in threaded mode, the view will expand all before selecting all
                 gDBView.doCommand(nsMsgViewCommandType.selectAll)
                 if (gDBView.numSelected != 1) {
+                    setTitleFromFolder(gDBView.msgFolder,null);
                     ClearMessagePane();
                 }
                 break;
@@ -190,6 +205,7 @@ var DefaultController =
 
 		switch ( command )
 		{
+      case "cmd_createFilterFromPopup":
 			case "cmd_close":
 			case "cmd_reply":
 			case "button_reply":
@@ -202,10 +218,10 @@ var DefaultController =
 			case "cmd_forwardInline":
 			case "cmd_forwardAttachment":
 			case "cmd_editAsNew":
+      case "cmd_createFilterFromMenu":
 			case "cmd_delete":
 			case "button_delete":
 			case "cmd_shiftDelete":
-			case "cmd_editDraft":
 			case "cmd_nextMsg":
       case "button_next":
 			case "cmd_nextUnreadMsg":
@@ -241,24 +257,31 @@ var DefaultController =
 			case "cmd_getNextNMessages":
 			case "cmd_find":
 			case "cmd_findAgain":
+      case "cmd_search":
       case "button_mark":
 			case "cmd_markAsRead":
 			case "cmd_markAllRead":
 			case "cmd_markThreadAsRead":
 			case "cmd_markAsFlagged":
+      case "cmd_label0":
+      case "cmd_label1":
+      case "cmd_label2":
+      case "cmd_label3":
+      case "cmd_label4":
+      case "cmd_label5":
       case "button_file":
 			case "cmd_file":
 			case "cmd_emptyTrash":
 			case "cmd_compactFolder":
 			case "cmd_sortByThread":
-      case "cmd_downloadFlagged":
-      case "cmd_downloadSelected":
-	  case "cmd_settingsOffline":
-      case "cmd_synchronizeOffline":
+  	  case "cmd_settingsOffline":
       case "cmd_close":
       case "cmd_selectThread":
-      case "cmd_selectFlagged":
 				return true;
+      case "cmd_downloadFlagged":
+      case "cmd_downloadSelected":
+      case "cmd_synchronizeOffline":
+        return(CheckOnline());
 
       case "cmd_watchThread":
       case "cmd_killThread":
@@ -271,41 +294,21 @@ var DefaultController =
 
   isCommandEnabled: function(command)
   {
+    //dump("DefaultController isCommandEnabled called" + command + "\n");
     var enabled = new Object();
     enabled.value = false;
     var checkStatus = new Object();
-//    dump('entering is command enabled for: ' + command + '\n');
+    
+    if (IsFakeAccount()) 
+      return false;
+
+    // note, all commands that get fired on a single key need to check MailAreaHasFocus() as well
     switch ( command )
     {
-      case "button_delete":
       case "cmd_delete":
-        var uri = GetFirstSelectedMessage();
-        if ( GetNumSelectedMessages() < 2 ) 
-        {
-          if (IsNewsMessage(uri))
-          {
-            goSetMenuValue(command, 'valueNewsMessage');
-            goSetAccessKey(command, 'valueNewsMessageAccessKey');
-          }
-          else
-          {
-            goSetMenuValue(command, 'valueMessage');
-            goSetAccessKey(command, 'valueMessageAccessKey');
-          }
-        }
-        else 
-        {
-          if (IsNewsMessage(uri)) 
-          {
-            goSetMenuValue(command, 'valueNewsMessage');
-            goSetAccessKey(command, 'valueNewsMessageAccessKey');
-          }
-          else 
-          {
-            goSetMenuValue(command, 'valueMessages');
-            goSetAccessKey(command, 'valueMessagesAccessKey');
-          }
-        }
+        UpdateDeleteCommand();
+        // fall through
+      case "button_delete":
         if (gDBView)
           gDBView.getCommandStatus(nsMsgViewCommandType.deleteMsg, enabled, checkStatus);
         return enabled.value;
@@ -316,9 +319,17 @@ var DefaultController =
       case "cmd_killThread":
         return ((GetNumSelectedMessages() == 1) && MailAreaHasFocus() && IsViewNavigationItemEnabled());
       case "cmd_watchThread":
-        if ((GetNumSelectedMessages() == 1) && gDBView)
+        if (MailAreaHasFocus() && (GetNumSelectedMessages() == 1) && gDBView)
           gDBView.getCommandStatus(nsMsgViewCommandType.toggleThreadWatched, enabled, checkStatus);
         return enabled.value;
+      case "cmd_createFilterFromPopup":
+        var loadedFolder = GetLoadedMsgFolder();
+        if (!(loadedFolder && loadedFolder.server.canHaveFilters))
+          return false;
+      case "cmd_createFilterFromMenu":
+        loadedFolder = GetLoadedMsgFolder();
+        if (!(loadedFolder && loadedFolder.server.canHaveFilters) || !(IsMessageDisplayedInMessagePane()))
+          return false;
       case "cmd_reply":
       case "button_reply":
       case "cmd_replySender":
@@ -348,32 +359,36 @@ var DefaultController =
         return false;
       case "cmd_printSetup":
         return true;
-      case "cmd_markThreadAsRead":
       case "cmd_markAsFlagged":
       case "button_file":
       case "cmd_file":
-        return ( GetNumSelectedMessages() > 0 );
-      case "cmd_editDraft":
-                return (gIsEditableMsgFolder && (GetNumSelectedMessages() > 0));
-      case "cmd_nextMsg":
+        return (GetNumSelectedMessages() > 0 );
+      case "button_mark":
+      case "cmd_markAsRead":
+      case "cmd_markThreadAsRead":
+      case "cmd_label0":
+      case "cmd_label1":
+      case "cmd_label2":
+      case "cmd_label3":
+      case "cmd_label4":
+      case "cmd_label5":
+        return(MailAreaHasFocus() && GetNumSelectedMessages() > 0);
       case "button_next":
+        return IsViewNavigationItemEnabled();
+      case "cmd_nextMsg":
       case "cmd_nextUnreadMsg":
       case "cmd_nextUnreadThread":
       case "cmd_previousMsg":
       case "cmd_previousUnreadMsg":
-        return MailAreaHasFocus() && IsViewNavigationItemEnabled();
-      case "button_mark":
-      case "cmd_markAsRead":
-        if(!MailAreaHasFocus())
-          return false;
-        else
-          return(GetNumSelectedMessages() > 0);
+        return (MailAreaHasFocus() && IsViewNavigationItemEnabled());
       case "cmd_markAllRead":
-        return(MailAreaHasFocus() && IsFolderSelected());
+        return (MailAreaHasFocus() && IsFolderSelected());
       case "cmd_find":
       case "cmd_findAgain":
-        return IsFindEnabled();
+        return IsMessageDisplayedInMessagePane();
         break;
+      case "cmd_search":
+        return IsCanSearchMessagesEnabled();
       // these are enabled on when we are in threaded mode
       case "cmd_selectThread":
         if (GetNumSelectedMessages() <= 0) return false;
@@ -391,6 +406,7 @@ var DefaultController =
       case "cmd_viewThreadsWithUnread":
       case "cmd_viewWatchedThreadsWithUnread":
       case "cmd_viewIgnoredThreads":
+      case "cmd_stop":
         return true;
       case "cmd_undo":
       case "cmd_redo":
@@ -399,10 +415,10 @@ var DefaultController =
         return IsRenameFolderEnabled();
       case "cmd_sendUnsentMsgs":
         return IsSendUnsentMsgsEnabled(null);
+      case "cmd_properties":
+        return IsPropertiesEnabled(command);
       case "button_getNewMessages":
       case "cmd_getNewMessages":
-      case "cmd_properties":
-        return IsPropertiesEnabled();
       case "cmd_getMsgsForAuthAccounts":
         return IsGetNewMessagesEnabled();
       case "cmd_getNextNMessages":
@@ -420,12 +436,9 @@ var DefaultController =
       case "cmd_downloadSelected":
         return(MailAreaHasFocus() && IsFolderSelected() && CheckOnline() && GetNumSelectedMessages() > 0);
       case "cmd_synchronizeOffline":
-        return IsAccountOfflineEnabled();       
+        return CheckOnline() && IsAccountOfflineEnabled();       
       case "cmd_settingsOffline":
         return (MailAreaHasFocus() && IsAccountOfflineEnabled());
-      case "cmd_selectFlagged":
-        // disable select flagged until I finish the code in nsMsgDBView.cpp
-        return false;
       default:
         return false;
     }
@@ -437,7 +450,7 @@ var DefaultController =
     // if the user invoked a key short cut then it is possible that we got here for a command which is
     // really disabled. kick out if the command should be disabled.
     if (!this.isCommandEnabled(command)) return;
-
+   
 		switch ( command )
 		{
 			case "cmd_close":
@@ -448,7 +461,6 @@ var DefaultController =
 				MsgGetMessage();
 				break;
       case "cmd_getMsgsForAuthAccounts":
-        MsgGetMessage();
         MsgGetMessagesForAllAuthenticatedAccounts();
         break;
 			case "cmd_getNextNMessages":
@@ -478,6 +490,11 @@ var DefaultController =
 			case "cmd_editAsNew":
 				MsgEditMessageAsNew();
 				break;
+      case "cmd_createFilterFromMenu":
+        MsgCreateFilter();
+        break;        
+      case "cmd_createFilterFromPopup":
+        break;// This does nothing because the createfilter is invoked from the popupnode oncommand.
 			case "button_delete":
 			case "cmd_delete":
         SetNextMessageAfterDelete();
@@ -494,10 +511,7 @@ var DefaultController =
       case "cmd_watchThread":
         gDBView.doCommand(nsMsgViewCommandType.toggleThreadWatched);
         break;
-			case "cmd_editDraft":
-                if (gDBView.numSelected >= 0)
-                    MsgComposeDraftMessage();
-				break;
+      case "button_next":
 			case "cmd_nextUnreadMsg":
 				MsgNextUnreadMessage();
 				break;
@@ -551,8 +565,8 @@ var DefaultController =
                 MsgOpenSelectedMessages();
 				return;
 			case "cmd_printSetup":
-			    goPageSetup();
-			    return;
+			  goPageSetup();
+			  return;
 			case "cmd_print":
 				PrintEnginePrint();
 				return;
@@ -580,6 +594,8 @@ var DefaultController =
             case "cmd_properties":
                 MsgFolderProperties();
                 return;
+      case "cmd_search":
+        MsgSearchMessages();
       case "button_mark":
 			case "cmd_markAsRead":
 				MsgMarkMsgAsRead(null);
@@ -590,9 +606,30 @@ var DefaultController =
 			case "cmd_markAllRead":
                 gDBView.doCommand(nsMsgViewCommandType.markAllRead);
 				return;
+      case "cmd_stop":
+        MsgStop();
+        return;
 			case "cmd_markAsFlagged":
 				MsgMarkAsFlagged(null);
 				return;
+      case "cmd_label0":
+        gDBView.doCommand(nsMsgViewCommandType.label0);
+ 				return;
+      case "cmd_label1":
+        gDBView.doCommand(nsMsgViewCommandType.label1);
+        return; 
+      case "cmd_label2":
+        gDBView.doCommand(nsMsgViewCommandType.label2);
+        return; 
+      case "cmd_label3":
+        gDBView.doCommand(nsMsgViewCommandType.label3);
+        return; 
+      case "cmd_label4":
+        gDBView.doCommand(nsMsgViewCommandType.label4);
+        return; 
+      case "cmd_label5":
+        gDBView.doCommand(nsMsgViewCommandType.label5);
+        return; 
 			case "cmd_emptyTrash":
 				MsgEmptyTrash();
 				return;
@@ -614,9 +651,6 @@ var DefaultController =
             case "cmd_selectThread":
                 gDBView.doCommand(nsMsgViewCommandType.selectThread);
                 break;
-            case "cmd_selectFlagged":
-                gDBView.doCommand(nsMsgViewCommandType.selectFlagged);
-                break;
 		}
 	},
 	
@@ -634,17 +668,27 @@ var DefaultController =
 
 function MailAreaHasFocus()
 {
-	//Input and TextAreas should get access to the keys that cause these commands.
-	//Currently if we don't do this then we will steal the key away and you can't type them
-	//in these controls. This is a bug that should be fixed and when it is we can get rid of
-	//this.
-	var focusedElement = top.document.commandDispatcher.focusedElement;
-	if(focusedElement)
-	{
-		var name = focusedElement.localName;
-		return ((name != "INPUT") && (name != "TEXTAREA"));
-	}
-	return true;
+  //Input and TextAreas should get access to the keys that cause these commands.
+  //Currently if we don't do this then we will steal the key away and you can't type them
+  //in these controls. This is a bug that should be fixed and when it is we can get rid of
+  //this.
+  var focusedElement = top.document.commandDispatcher.focusedElement;
+  if (focusedElement) 
+  {
+    var name = focusedElement.localName.toLowerCase();
+    return ((name != "input") && (name != "textarea"));
+  }
+
+  // check if the message pane has focus 
+  // see bug #129988
+  if (GetMessagePane() == WhichPaneHasFocus())
+    return true;
+
+  // if there is no focusedElement,
+  // and the message pane doesn't have focus
+  // then a mail area can't be focused
+  // see bug #128101
+  return false;
 }
 
 function GetNumSelectedMessages()
@@ -657,122 +701,69 @@ function GetNumSelectedMessages()
     }
 }
 
-var lastFocusedElement=null;
+var gLastFocusedElement=null;
 
 function FocusRingUpdate_Mail()
 {
-  //dump ('entering focus ring update\n');
+  // WhichPaneHasFocus() uses on top.document.commandDispatcher.focusedElement
+  // to determine which pane has focus
+  // if the focusedElement is null, we're here on a blur.
+  // nsFocusController::Blur() calls nsFocusController::SetFocusedElement(null), 
+  // which will update any commands listening for "focus".
+  // we really only care about nsFocusController::Focus() happens, 
+  // which calls nsFocusController::SetFocusedElement(element)
   var currentFocusedElement = WhichPaneHasFocus();
   if (!currentFocusedElement)
-  {
-     // dump ('setting default focus to message pane');
-     currentFocusedElement = GetMessagePane();
+    return;
+      
+	if (currentFocusedElement != gLastFocusedElement) {
+    currentFocusedElement.setAttribute("focusring", "true");
+    
+    if (gLastFocusedElement)
+      gLastFocusedElement.removeAttribute("focusring");
+
+    gLastFocusedElement = currentFocusedElement;
+
+    // since we just changed the pane with focus we need to update the toolbar to reflect this
+    UpdateMailToolbar("focus");
   }
-    
-	if(currentFocusedElement != lastFocusedElement) {
-        if( currentFocusedElement == GetThreadOutliner()) {
-            // XXX fix me
-            GetThreadOutliner().setAttribute("focusring","true");
-            GetMessagePane().setAttribute("focusring","false");
-        }
-
-        else if(currentFocusedElement==GetFolderOutliner()) {
-            // XXX fix me
-            GetThreadOutliner().setAttribute("focusring","false");
-            GetMessagePane().setAttribute("focusring","false");
-        }
-        else if(currentFocusedElement==GetMessagePane()){
-            // mscott --> fix me!!
-            GetThreadOutliner().setAttribute("focusring","false");
-            GetMessagePane().setAttribute("focusring","true");
-        }
-        else {
-            // XXX fix me
-            GetThreadOutliner().setAttribute("focusring","false");
-            GetMessagePane().setAttribute("focusring","false");
-        }
-        
-        lastFocusedElement=currentFocusedElement;
-
-        // since we just changed the pane with focus we need to update the toolbar to reflect this
-        document.commandDispatcher.updateCommands('mail-toolbar');
-    }
-//    else
-//      dump('current focused element matched last focused element\n');
 }
 
-function MessagePaneHasFocus()
+function WhichPaneHasFocus()
 {
-  // message pane has focus if the iframe has focus OR if the message pane box
-  // has focus....
-  // first, check to see if the message pane box has focus...if it does, return true
+  var threadTree = GetThreadTree();
+  var searchInput = GetSearchInput();
+  var folderTree = GetFolderTree();
   var messagePane = GetMessagePane();
-  if (WhichPaneHasFocus() == messagePane)
-    return true;
+    
+  if (top.document.commandDispatcher.focusedWindow == GetMessagePaneFrame())
+    return messagePane;
 
-  // second, check to see if the iframe has focus...if it does, return true....
-
-  // check to see if the iframe has focus...
-	var focusedWindow = top.document.commandDispatcher.focusedWindow;
-	var messagePaneWindow = top.frames['messagepane'];
-	
-	if ( focusedWindow && messagePaneWindow && (focusedWindow != top) )
-	{        
-		var hasFocus = IsSubWindowOf(focusedWindow, messagePaneWindow);
-		return hasFocus;
-	}
-	
-	return false;
-}
-
-function IsSubWindowOf(search, wind)
-{
-	//dump("IsSubWindowOf(" + search + ", " + wind + ", " + found + ")\n");
-	if (search == wind)
-		return true;
-	
-	for ( index = 0; index < wind.frames.length; index++ )
-	{
-		if ( IsSubWindowOf(search, wind.frames[index]) )
-			return true;
-	}
-	return false;
-}
-
-
-function WhichPaneHasFocus(){
-	var whichPane= null;
 	var currentNode = top.document.commandDispatcher.focusedElement;	
-
-  var threadOutliner = GetThreadOutliner();
-  var folderOutliner = GetFolderOutliner();
-  var messagePane = GetMessagePane();
-    
 	while (currentNode) {
-        if (currentNode === threadOutliner ||
-            currentNode === folderOutliner ||
-            currentNode === messagePane)
-            return currentNode;
-					
-			currentNode = currentNode.parentNode;
-    }
+    if (currentNode === threadTree ||
+        currentNode === searchInput || 
+        currentNode === folderTree ||
+        currentNode === messagePane)
+      return currentNode;
+    			
+		currentNode = currentNode.parentNode;
+  }
 	
 	return null;
 }
 
 function SetupCommandUpdateHandlers()
 {
-	//dump("SetupCommandUpdateHandlers\n");
-
 	var widget;
 	
 	// folder pane
-	widget = GetFolderOutliner();
+	widget = GetFolderTree();
 	if ( widget )
 		widget.controllers.appendController(FolderPaneController);
 	
 	// thread pane
-	widget = GetThreadOutliner();
+	widget = GetThreadTree();
 	if ( widget )
         widget.controllers.appendController(ThreadPaneController);
 		
@@ -821,29 +812,62 @@ function IsSendUnsentMsgsEnabled(folderResource)
 
 function IsRenameFolderEnabled()
 {
-    var folderOutliner = GetFolderOutliner();
-    var selection = folderOutliner.outlinerBoxObject.selection;
+    var folderTree = GetFolderTree();
+    var selection = folderTree.treeBoxObject.selection;
     if (selection.count == 1)
     {
         var startIndex = {};
         var endIndex = {};
         selection.getRangeAt(0, startIndex, endIndex);
-        var folderResource = GetFolderResource(folderOutliner, startIndex.value);
-        var canRename = GetFolderAttribute(folderOutliner, folderResource, "CanRename") == "true";
+        var folderResource = GetFolderResource(folderTree, startIndex.value);
+        var canRename = GetFolderAttribute(folderTree, folderResource, "CanRename") == "true";
         return canRename && isCommandEnabled("cmd_renameFolder");
     }
     else
         return false;
 }
 
+function IsCanSearchMessagesEnabled()
+{
+  var folderURI = GetSelectedFolderURI();
+  var server = GetServer(folderURI);
+  return server.canSearchMessages;
+}
 function IsFolderCharsetEnabled()
 {
   return IsFolderSelected();
 }
 
-function IsPropertiesEnabled()
+function IsPropertiesEnabled(command)
 {
+   try 
+   {
+      var serverType;
+      var folderTree = GetFolderTree();
+      var folderResource = GetSelectedFolderResource();
+      
+      serverType = GetFolderAttribute(folderTree, folderResource, "ServerType");
+   
+      switch (serverType)
+      {
+        case "none":
+        case "imap":
+        case "pop3":
+          goSetMenuValue(command, 'valueFolder');
+          break;
+        case "nntp":
+          goSetMenuValue(command, 'valueNewsgroup');
+          break
+        default:
+          goSetMenuValue(command, 'valueGeneric');
+      }
+   }
+   catch (ex) 
+   {
+      //properties menu failure
+   }
   return IsFolderSelected();
+  
 }
 
 function IsViewNavigationItemEnabled()
@@ -853,34 +877,34 @@ function IsViewNavigationItemEnabled()
 
 function IsFolderSelected()
 {
-    var folderOutliner = GetFolderOutliner();
-    var selection = folderOutliner.outlinerBoxObject.selection;
+    var folderTree = GetFolderTree();
+    var selection = folderTree.treeBoxObject.selection;
     if (selection.count == 1)
     {
         var startIndex = {};
         var endIndex = {};
         selection.getRangeAt(0, startIndex, endIndex);
-        var folderResource = GetFolderResource(folderOutliner, startIndex.value);
-        return GetFolderAttribute(folderOutliner, folderResource, "IsServer") != "true";
+        var folderResource = GetFolderResource(folderTree, startIndex.value);
+        return GetFolderAttribute(folderTree, folderResource, "IsServer") != "true";
     }
     else
         return false;
 }
 
-function IsFindEnabled()
+function IsMessageDisplayedInMessagePane()
 {
 	return (!IsThreadAndMessagePaneSplitterCollapsed() && (GetNumSelectedMessages() > 0));
 }
 
 function MsgDeleteFolder()
 {
-    var folderOutliner = GetFolderOutliner();
+    var folderTree = GetFolderTree();
     var selectedFolders = GetSelectedMsgFolders();
     for (var i = 0; i < selectedFolders.length; i++)
     {
         var selectedFolder = selectedFolders[i];
         var folderResource = selectedFolder.QueryInterface(Components.interfaces.nsIRDFResource);
-        var specialFolder = GetFolderAttribute(folderOutliner, folderResource, "SpecialFolder");
+        var specialFolder = GetFolderAttribute(folderTree, folderResource, "SpecialFolder");
         if (specialFolder != "Inbox" && specialFolder != "Trash")
         {
             var protocolInfo = Components.classes["@mozilla.org/messenger/protocol/info;1?type=" + selectedFolder.server.type].getService(Components.interfaces.nsIMsgProtocolInfo);
@@ -912,6 +936,15 @@ function MsgDeleteFolder()
     }
 }
 
+function SetFocusThreadPaneIfNotOnMessagePane()
+{
+  var focusedElement = WhichPaneHasFocus();
+
+  if((focusedElement != GetThreadTree()) &&
+     (focusedElement != GetMessagePane()))
+     SetFocusThreadPane();
+}
+
 // 3pane related commands.  Need to go in own file.  Putting here for the moment.
 function MsgNextMessage()
 {
@@ -949,25 +982,11 @@ function MsgPreviousFlaggedMessage()
 	GoNextMessage(nsMsgNavigationType.previousFlagged, true);
 }
 
-function MsgViewAllMsgs() 
-{
-	//dump("MsgViewAllMsgs\n");
-	if(gDBView)
-	{
-		gDBView.viewType = nsMsgViewType.eShowAllThreads;
-
-        var folder = GetSelectedFolder();
-        if(folder) {
-            folder.setAttribute("viewType", nsMsgViewType.eShowAllThreads);
-        }
-	}
-}
-
-function GetFolderNameFromUri(uri, outliner)
+function GetFolderNameFromUri(uri, tree)
 {
 	var folderResource = RDF.GetResource(uri);
 
-	var db = outliner.outlinerBoxObject.outlinerBody.database;
+	var db = tree.database;
 
 	var nameProperty = RDF.GetResource('http://home.netscape.com/NC-rdf#Name');
 
@@ -983,111 +1002,79 @@ function GetFolderNameFromUri(uri, outliner)
 	return nameResult.Value;
 }
 
-function SwitchPaneFocus(direction)
+/* XXX hiding the search bar while it is focus kills the keyboard so we focus the thread pane */
+function SearchBarToggled()
 {
-  var gray_vertical_splitter = document.getElementById("gray_vertical_splitter"); 
-  var focusedElement = document.commandDispatcher.focusedElement;
-  var focusedElementId;
-  if (direction == "counter-clockwise")
-	{
-		if ( MessagePaneHasFocus() )
-			SetFocusThreadPane();
-		else 
-		{
-			try 
-			{ 
-				focusedElementId = focusedElement.getAttribute('id');
-				if(focusedElementId == "threadOutliner")
-				{
-					if (gray_vertical_splitter)
-					{
-						if (!(is_collapsed(gray_vertical_splitter)))
-						  SetFocusFolderPane();
-						else if(!(IsThreadAndMessagePaneSplitterCollapsed()))
-						  SetFocusMessagePane();
-					}
-					else 
-					{
-						if (!(sidebar_is_collapsed()))
-						  SetFocusFolderPane();
-						else if(!(IsThreadAndMessagePaneSplitterCollapsed()))
-						  SetFocusMessagePane();
-					}
-				}
-				else if(focusedElementId == "folderOutliner")
-				{
-					if (!(IsThreadAndMessagePaneSplitterCollapsed()))
-						SetFocusMessagePane();
-					else
-						SetFocusThreadPane();
-				}
-			}
-			catch(e) 
-			{
-				SetFocusMessagePane();
-			}
-		}
-	}
-	else
-	{
+  var searchBox = document.getElementById('searchBox');
+  if (searchBox)
+  {
+    var attribValue = searchBox.getAttribute("hidden") ;
+    if (attribValue == "true")
+    {
+      /*come out of quick search view */
+      if (gDBView && gDBView.isSearchView)
+        onClearSearch();
+    }
+    else
+    {
+      /*we have to initialize searchInput because we cannot do it when searchBox is hidden */
+      var searchInput = GetSearchInput();
+      searchInput.value="";
+    }
+  }
 
-		if ( MessagePaneHasFocus() )
-		{
-			if (gray_vertical_splitter)
-			{
-				if (!(is_collapsed(gray_vertical_splitter)))
-					SetFocusFolderPane();
-				else
-					SetFocusThreadPane();
-			}
-			else 
-			{
-				if (!(sidebar_is_collapsed()))
-				  SetFocusFolderPane();
-				else
-				  SetFocusThreadPane();
-			}
-		}
-		else 
-		{
-			try 
-			{ 
-				focusedElementId = focusedElement.getAttribute('id');
-				if(focusedElementId == "threadOutliner")
-				{
-					if (!(IsThreadAndMessagePaneSplitterCollapsed()))
-						SetFocusMessagePane();
-					else if (gray_vertical_splitter)
-					{
-						if (!(is_collapsed(gray_vertical_splitter)))
-						SetFocusFolderPane();
-					}
-					else if (!(sidebar_is_collapsed()))
-						SetFocusFolderPane();
+  for (var currentNode = top.document.commandDispatcher.focusedElement; currentNode; currentNode = currentNode.parentNode) {
+    if (currentNode.getAttribute("hidden") == "true") {
+      SetFocusThreadPane();
+      return;
+    }
+  }
+}
 
-				}
-				else if(focusedElementId == "folderOutliner")
-					SetFocusThreadPane();
-			}
-			catch(e) 
-			{
-				SetFocusMessagePane();
-			}
-		}
-	}
+function SwitchPaneFocus(event)
+{
+  var focusedElement = WhichPaneHasFocus();
+  var folderTree = GetFolderTree();
+  var threadTree = GetThreadTree();
+  var searchInput = GetSearchInput();
+  var messagePane = GetMessagePane();
 
+  if (event && event.shiftKey)
+  {
+    if (focusedElement == threadTree && searchInput.parentNode.getAttribute('hidden') != 'true')
+      searchInput.focus();
+    else if ((focusedElement == threadTree || focusedElement == searchInput) && !IsFolderPaneCollapsed())
+      folderTree.focus();
+    else if (focusedElement != messagePane && !IsThreadAndMessagePaneSplitterCollapsed())
+      SetFocusMessagePane();
+    else 
+      threadTree.focus();
+  }
+  else
+  {
+    if (focusedElement == searchInput)
+      threadTree.focus();
+    else if (focusedElement == threadTree && !IsThreadAndMessagePaneSplitterCollapsed())
+      SetFocusMessagePane();
+    else if (focusedElement != folderTree && !IsFolderPaneCollapsed())
+      folderTree.focus();
+    else if (searchInput.parentNode.getAttribute('hidden') != 'true')
+      searchInput.focus();
+    else
+      threadTree.focus();
+  }
 }
 
 function SetFocusFolderPane()
 {
-    var folderOutliner = GetFolderOutliner();
-    folderOutliner.focus();
+    var folderTree = GetFolderTree();
+    folderTree.focus();
 }
 
 function SetFocusThreadPane()
 {
-    var threadOutliner = GetThreadOutliner();
-    threadOutliner.focus();
+    var threadTree = GetThreadTree();
+    threadTree.focus();
 }
 
 function SetFocusMessagePane()
@@ -1116,3 +1103,22 @@ function isCommandEnabled(cmd)
 
 }
 
+function IsFakeAccount() {
+  try {
+    var folderResource = GetSelectedFolderResource();
+    return (folderResource.Value == "http://home.netscape.com/NC-rdf#PageTitleFakeAccount");
+  }
+  catch(ex) {
+  }
+  return false;
+}
+
+function SendCommandToThreadPane(command)
+{
+  ThreadPaneController.doCommand(command);
+ 
+  // if we are sending the command so the thread pane
+  // we should focus the thread pane
+  SetFocusThreadPane();
+}
+
