@@ -12,6 +12,7 @@ nsJSAimChatRendezvous.prototype = {
     OnBuddyIconProposalReceived : function (screenname, proposal)
     {
 
+
      inviteArgsObj = {
      	inviteProposalScreenName: screenname, 
      	inviteProposalObj: proposal,
@@ -20,10 +21,10 @@ nsJSAimChatRendezvous.prototype = {
      	inviteMode: 'incomingchat'
      }
     
-     //var windowManager = Components.classes['@mozilla.org/rdf/datasource;1?name=window-mediator'].getService();
+     var windowManager = Components.classes['@mozilla.org/rdf/datasource;1?name=window-mediator'].getService();
+
+     var windowManagerInterface = windowManager.QueryInterface( Components.interfaces.nsIWindowMediator);
 
-     //var windowManagerInterface = windowManager.QueryInterface( Components.interfaces.nsIWindowMediator);
-     var windowManagerInterface = Components.classes["@mozilla.org/appshell/window-mediator;1"].getService(Components.interfaces.nsIWindowMediator);
      var topWindow = windowManagerInterface.getMostRecentWindow(null);
 
      //topWindow.focus();
@@ -44,11 +45,10 @@ nsJSAimChatRendezvous.prototype = {
      	inviteMode: 'incomingchat'
      }
     
-     //var windowManager = Components.classes['@mozilla.org/rdf/datasource;1?name=window-mediator'].getService();
+     var windowManager = Components.classes['@mozilla.org/rdf/datasource;1?name=window-mediator'].getService();
 
-     //var windowManagerInterface = windowManager.QueryInterface( Components.interfaces.nsIWindowMediator);
+     var windowManagerInterface = windowManager.QueryInterface( Components.interfaces.nsIWindowMediator);
 
-     var windowManagerInterface = Components.classes["@mozilla.org/appshell/window-mediator;1"].getService(Components.interfaces.nsIWindowMediator);
      var topWindow = windowManagerInterface.getMostRecentWindow(null);
 
      //topWindow.focus();
@@ -69,11 +69,10 @@ nsJSAimChatRendezvous.prototype = {
 			invitationmsg: msg
   }
     
-		//var windowManager = Components.classes['@mozilla.org/rdf/datasource;1?name=window-mediator'].getService();
+		var windowManager = Components.classes['@mozilla.org/rdf/datasource;1?name=window-mediator'].getService();
 
-		//var windowManagerInterface = windowManager.QueryInterface( Components.interfaces.nsIWindowMediator);
+		var windowManagerInterface = windowManager.QueryInterface( Components.interfaces.nsIWindowMediator);
 
-    var windowManagerInterface = Components.classes["@mozilla.org/appshell/window-mediator;1"].getService(Components.interfaces.nsIWindowMediator);
 		var topWindow = windowManagerInterface.getMostRecentWindow(null);
 		topWindow.openDialog('chrome://aim/content/chatInviteBuddy.xul','_blank','chrome,all,dialog=no',inviteArgsObj); 
 	},
@@ -90,12 +89,11 @@ nsJSAimChatRendezvous.prototype = {
 			fromurl : true
      		}
     
-		//var windowManager = Components.classes['@mozilla.org/rdf/datasource;1?name=window-mediator'].getService();
+		var windowManager = Components.classes['@mozilla.org/rdf/datasource;1?name=window-mediator'].getService();
 
-		//var	windowManagerInterface = windowManager.QueryInterface( Components.interfaces.nsIWindowMediator);
+		var	windowManagerInterface = windowManager.QueryInterface( Components.interfaces.nsIWindowMediator);
 
-		var windowManagerInterface = Components.classes["@mozilla.org/appshell/window-mediator;1"].getService(Components.interfaces.nsIWindowMediator);
-    var topWindow = windowManagerInterface.getMostRecentWindow(null);
+		var topWindow = windowManagerInterface.getMostRecentWindow(null);
 
 		topWindow.openDialog('chrome://aim/content/chatContent.xul','','chrome,all,dialog=no',chatContentArgsObj); 
 	}
