@@ -6,6 +6,8 @@ pref("addressbook.throbber.url","chrome://messenger-region/locale/region-ns.prop
 pref("mail.absync.port",5001);
 pref("mail.absync.server","mailwsg.mcom.com/_cqr/sync");
 pref("mail.absync.firsttime",true);
+pref("mail.absync.client_map._AimScreenName","screen_name"); // support only one generic sync column
+pref("mail.absync.server_map.screen_name","_AimScreenName"); // support only one generic sync column
 pref("mailnews.reply_on_top", 1);
 pref("mail.display_struct", false);
 pref("mail.forward_message_mode", 2); // 0=default as attachment 2=forward as inline with attachments, (obsolete)1=forward as quoted
@@ -17,7 +19,7 @@ pref("default_offline_support_level.imap.mail.netcenter.com", 10);
 // for default_redirector_type, see bugscape bugs #19665 and #20069
 // format is "default_redirector_type." + protocol + "." + hostname
 pref("default_redirector_type.imap.mail.aol.com","aol");
-pref("default_redirector_type.imap.mail.netcenter.com","netscape");
+pref("default_redirector_type.imap.mail.netcenter.com","netscape");    
 pref("default_redirector_type.smtp.smtp.aol.com","aol");
 pref("default_redirector_type.smtp.smtp.netscape.net","netscape");
 
@@ -37,26 +39,16 @@ pref("imap.aol.canSearchMessages", false);
 pref("imap.aol.canFileMessages", false);
 pref("imap.aol.canSearchMessages", false);
 pref("imap.aol.emptyTrashOnExit", false);
-pref("imap.aol.showMessagesAfterLoading",true);
-
-pref("imap.netscape.canSearchMessages", false);
-pref("imap.netscape.isSecureServer", false);
-
-// hide hostname when prompting for password for these types
-// see bugscape bugs #19993 and #20196
-// format is protocol + "." + redirector_type + ".hide_hostname_for_password"
-pref("imap.aol.hide_hostname_for_password",true);
-pref("imap.netscape.hide_hostname_for_password",true);
-pref("smtp.aol.hide_hostname_for_password",true);
-pref("smtp.netscape.hide_hostname_for_password",true);
-
 pref("mailnews.bannerad.alternateDisplay", false);
 pref("mailnews.global_html_domains", "netscape.net,netscape.com,aol.com,cs.com,yahoo.com,hotmail.com,msn.com");
 pref("mail.aol.unreadMailCountRegistryKeyPrefix", "America Online - ");
 pref("mailnews.fakeaccount.show", true);
 pref("mailnews.fakeaccount.server", "imap.mail.netcenter.com");
-pref("mail.accountmanager.aol.hide_advanced_button", true);
-pref("mail.accountmanager.netscape.hide_advanced_button", true);
+
 /* ns tree specific prefs */
 pref("browser.toolbars.showbutton.mailPT", true);
 
+// special enhancements for IMAP servers
+pref("mail.server.default.store_read_mail_in_pfc", false);
+pref("mail.server.default.store_sent_mail_in_pfc", false);
+
